// This file is generated by kconfig_compiler_kf6 from konversation.kcfg.
// All changes you do to this file will be lost.
#ifndef PREFERENCESBASE_H
#define PREFERENCESBASE_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

#include <qfont.h>
#include <qsize.h>
#include <QDir>
#include <kuser.h>
#include <QStandardPaths>
#include <QFontDatabase>
#include <QUrl>
#include <QStyle>
#include <QApplication>

class PreferencesBase : public KConfigSkeleton
{
  public:
    enum EnumLauncherEntryCountMode { CountEvents, CountChannelAndQueries };
    enum EnumTabPlacement { Top, Bottom, Left };
    enum EnumColorName { ActionMessage, BacklogMessage, ChannelMessage, CommandMessage, QueryMessage, ServerMessage, Time, Action, TextViewBackground, AlternateBackground, Hyperlink };
    static const char* const EnumColorNameToString[];
    enum EnumProxyType { Socksv5Proxy, HTTPProxy };

    PreferencesBase( );
    ~PreferencesBase() override;

    /**
      Set ShowMenuBar
    */
    void setShowMenuBar( bool v )
    {
      if (!isShowMenuBarImmutable())
        mShowMenuBar = v;
    }

    /**
      Get ShowMenuBar
    */
    bool showMenuBar() const
    {
      return mShowMenuBar;
    }

    /**
      Is ShowMenuBar Immutable
    */
    bool isShowMenuBarImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowMenuBar" ) );
    }

    /**
      Get Item object corresponding to ShowMenuBar()
    */
    ItemBool *showMenuBarItem()
    {
      return mShowMenuBarItem;
    }

    /**
      Set TextFont
    */
    void setTextFont( const QFont & v )
    {
      if (!isTextFontImmutable())
        mTextFont = v;
    }

    /**
      Get TextFont
    */
    QFont textFont() const
    {
      return mTextFont;
    }

    /**
      Is TextFont Immutable
    */
    bool isTextFontImmutable() const
    {
      return isImmutable( QStringLiteral( "TextFont" ) );
    }

    /**
      Get Item object corresponding to TextFont()
    */
    ItemFont *textFontItem()
    {
      return mTextFontItem;
    }

    /**
      Set ListFont
    */
    void setListFont( const QFont & v )
    {
      if (!isListFontImmutable())
        mListFont = v;
    }

    /**
      Get ListFont
    */
    QFont listFont() const
    {
      return mListFont;
    }

    /**
      Is ListFont Immutable
    */
    bool isListFontImmutable() const
    {
      return isImmutable( QStringLiteral( "ListFont" ) );
    }

    /**
      Get Item object corresponding to ListFont()
    */
    ItemFont *listFontItem()
    {
      return mListFontItem;
    }

    /**
      Set TabFont
    */
    void setTabFont( const QFont & v )
    {
      if (!isTabFontImmutable())
        mTabFont = v;
    }

    /**
      Get TabFont
    */
    QFont tabFont() const
    {
      return mTabFont;
    }

    /**
      Is TabFont Immutable
    */
    bool isTabFontImmutable() const
    {
      return isImmutable( QStringLiteral( "TabFont" ) );
    }

    /**
      Get Item object corresponding to TabFont()
    */
    ItemFont *tabFontItem()
    {
      return mTabFontItem;
    }

    /**
      Set CustomTextFont
    */
    void setCustomTextFont( bool v )
    {
      if (!isCustomTextFontImmutable())
        mCustomTextFont = v;
    }

    /**
      Get CustomTextFont
    */
    bool customTextFont() const
    {
      return mCustomTextFont;
    }

    /**
      Is CustomTextFont Immutable
    */
    bool isCustomTextFontImmutable() const
    {
      return isImmutable( QStringLiteral( "CustomTextFont" ) );
    }

    /**
      Get Item object corresponding to CustomTextFont()
    */
    ItemBool *customTextFontItem()
    {
      return mCustomTextFontItem;
    }

    /**
      Set CustomListFont
    */
    void setCustomListFont( bool v )
    {
      if (!isCustomListFontImmutable())
        mCustomListFont = v;
    }

    /**
      Get CustomListFont
    */
    bool customListFont() const
    {
      return mCustomListFont;
    }

    /**
      Is CustomListFont Immutable
    */
    bool isCustomListFontImmutable() const
    {
      return isImmutable( QStringLiteral( "CustomListFont" ) );
    }

    /**
      Get Item object corresponding to CustomListFont()
    */
    ItemBool *customListFontItem()
    {
      return mCustomListFontItem;
    }

    /**
      Set CustomTabFont
    */
    void setCustomTabFont( bool v )
    {
      if (!isCustomTabFontImmutable())
        mCustomTabFont = v;
    }

    /**
      Get CustomTabFont
    */
    bool customTabFont() const
    {
      return mCustomTabFont;
    }

    /**
      Is CustomTabFont Immutable
    */
    bool isCustomTabFontImmutable() const
    {
      return isImmutable( QStringLiteral( "CustomTabFont" ) );
    }

    /**
      Get Item object corresponding to CustomTabFont()
    */
    ItemBool *customTabFontItem()
    {
      return mCustomTabFontItem;
    }

    /**
      Set Timestamping
    */
    void setTimestamping( bool v )
    {
      if (!isTimestampingImmutable())
        mTimestamping = v;
    }

    /**
      Get Timestamping
    */
    bool timestamping() const
    {
      return mTimestamping;
    }

    /**
      Is Timestamping Immutable
    */
    bool isTimestampingImmutable() const
    {
      return isImmutable( QStringLiteral( "Timestamping" ) );
    }

    /**
      Get Item object corresponding to Timestamping()
    */
    ItemBool *timestampingItem()
    {
      return mTimestampingItem;
    }

    /**
      Set ShowDate
    */
    void setShowDate( bool v )
    {
      if (!isShowDateImmutable())
        mShowDate = v;
    }

    /**
      Get ShowDate
    */
    bool showDate() const
    {
      return mShowDate;
    }

    /**
      Is ShowDate Immutable
    */
    bool isShowDateImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowDate" ) );
    }

    /**
      Get Item object corresponding to ShowDate()
    */
    ItemBool *showDateItem()
    {
      return mShowDateItem;
    }

    /**
      Set ShowDateLine
    */
    void setShowDateLine( bool v )
    {
      if (!isShowDateLineImmutable())
        mShowDateLine = v;
    }

    /**
      Get ShowDateLine
    */
    bool showDateLine() const
    {
      return mShowDateLine;
    }

    /**
      Is ShowDateLine Immutable
    */
    bool isShowDateLineImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowDateLine" ) );
    }

    /**
      Get Item object corresponding to ShowDateLine()
    */
    ItemBool *showDateLineItem()
    {
      return mShowDateLineItem;
    }

    /**
      Set TimestampFormat
    */
    void setTimestampFormat( const QString & v )
    {
      if (!isTimestampFormatImmutable())
        mTimestampFormat = v;
    }

    /**
      Get TimestampFormat
    */
    QString timestampFormat() const
    {
      return mTimestampFormat;
    }

    /**
      Is TimestampFormat Immutable
    */
    bool isTimestampFormatImmutable() const
    {
      return isImmutable( QStringLiteral( "TimestampFormat" ) );
    }

    /**
      Get Item object corresponding to TimestampFormat()
    */
    ItemString *timestampFormatItem()
    {
      return mTimestampFormatItem;
    }

    /**
      Set ShowBacklog
    */
    void setShowBacklog( bool v )
    {
      if (!isShowBacklogImmutable())
        mShowBacklog = v;
    }

    /**
      Get ShowBacklog
    */
    bool showBacklog() const
    {
      return mShowBacklog;
    }

    /**
      Is ShowBacklog Immutable
    */
    bool isShowBacklogImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowBacklog" ) );
    }

    /**
      Get Item object corresponding to ShowBacklog()
    */
    ItemBool *showBacklogItem()
    {
      return mShowBacklogItem;
    }

    /**
      Set BacklogLines
    */
    void setBacklogLines( int v )
    {
      if (!isBacklogLinesImmutable())
        mBacklogLines = v;
    }

    /**
      Get BacklogLines
    */
    int backlogLines() const
    {
      return mBacklogLines;
    }

    /**
      Is BacklogLines Immutable
    */
    bool isBacklogLinesImmutable() const
    {
      return isImmutable( QStringLiteral( "BacklogLines" ) );
    }

    /**
      Get Item object corresponding to BacklogLines()
    */
    ItemInt *backlogLinesItem()
    {
      return mBacklogLinesItem;
    }

    /**
      Set ShowNickList
    */
    void setShowNickList( bool v )
    {
      if (!isShowNickListImmutable())
        mShowNickList = v;
    }

    /**
      Get ShowNickList
    */
    bool showNickList() const
    {
      return mShowNickList;
    }

    /**
      Is ShowNickList Immutable
    */
    bool isShowNickListImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowNickList" ) );
    }

    /**
      Get Item object corresponding to ShowNickList()
    */
    ItemBool *showNickListItem()
    {
      return mShowNickListItem;
    }

    /**
      Set ShowQuickButtons
    */
    void setShowQuickButtons( bool v )
    {
      if (!isShowQuickButtonsImmutable())
        mShowQuickButtons = v;
    }

    /**
      Get ShowQuickButtons
    */
    bool showQuickButtons() const
    {
      return mShowQuickButtons;
    }

    /**
      Is ShowQuickButtons Immutable
    */
    bool isShowQuickButtonsImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowQuickButtons" ) );
    }

    /**
      Get Item object corresponding to ShowQuickButtons()
    */
    ItemBool *showQuickButtonsItem()
    {
      return mShowQuickButtonsItem;
    }

    /**
      Set ShowQuickButtonsInContextMenu
    */
    void setShowQuickButtonsInContextMenu( bool v )
    {
      if (!isShowQuickButtonsInContextMenuImmutable())
        mShowQuickButtonsInContextMenu = v;
    }

    /**
      Get ShowQuickButtonsInContextMenu
    */
    bool showQuickButtonsInContextMenu() const
    {
      return mShowQuickButtonsInContextMenu;
    }

    /**
      Is ShowQuickButtonsInContextMenu Immutable
    */
    bool isShowQuickButtonsInContextMenuImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowQuickButtonsInContextMenu" ) );
    }

    /**
      Get Item object corresponding to ShowQuickButtonsInContextMenu()
    */
    ItemBool *showQuickButtonsInContextMenuItem()
    {
      return mShowQuickButtonsInContextMenuItem;
    }

    /**
      Set ShowModeButtons
    */
    void setShowModeButtons( bool v )
    {
      if (!isShowModeButtonsImmutable())
        mShowModeButtons = v;
    }

    /**
      Get ShowModeButtons
    */
    bool showModeButtons() const
    {
      return mShowModeButtons;
    }

    /**
      Is ShowModeButtons Immutable
    */
    bool isShowModeButtonsImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowModeButtons" ) );
    }

    /**
      Get Item object corresponding to ShowModeButtons()
    */
    ItemBool *showModeButtonsItem()
    {
      return mShowModeButtonsItem;
    }

    /**
      Set CloseButtons
    */
    void setCloseButtons( bool v )
    {
      if (!isCloseButtonsImmutable())
        mCloseButtons = v;
    }

    /**
      Get CloseButtons
    */
    bool closeButtons() const
    {
      return mCloseButtons;
    }

    /**
      Is CloseButtons Immutable
    */
    bool isCloseButtonsImmutable() const
    {
      return isImmutable( QStringLiteral( "CloseButtons" ) );
    }

    /**
      Get Item object corresponding to CloseButtons()
    */
    ItemBool *closeButtonsItem()
    {
      return mCloseButtonsItem;
    }

    /**
      Set AutoUserhost
    */
    void setAutoUserhost( bool v )
    {
      if (!isAutoUserhostImmutable())
        mAutoUserhost = v;
    }

    /**
      Get AutoUserhost
    */
    bool autoUserhost() const
    {
      return mAutoUserhost;
    }

    /**
      Is AutoUserhost Immutable
    */
    bool isAutoUserhostImmutable() const
    {
      return isImmutable( QStringLiteral( "AutoUserhost" ) );
    }

    /**
      Get Item object corresponding to AutoUserhost()
    */
    ItemBool *autoUserhostItem()
    {
      return mAutoUserhostItem;
    }

    /**
      Set UseSpacing
    */
    void setUseSpacing( bool v )
    {
      if (!isUseSpacingImmutable())
        mUseSpacing = v;
    }

    /**
      Get UseSpacing
    */
    bool useSpacing() const
    {
      return mUseSpacing;
    }

    /**
      Is UseSpacing Immutable
    */
    bool isUseSpacingImmutable() const
    {
      return isImmutable( QStringLiteral( "UseSpacing" ) );
    }

    /**
      Get Item object corresponding to UseSpacing()
    */
    ItemBool *useSpacingItem()
    {
      return mUseSpacingItem;
    }

    /**
      Set Spacing
    */
    void setSpacing( int v )
    {
      if (!isSpacingImmutable())
        mSpacing = v;
    }

    /**
      Get Spacing
    */
    int spacing() const
    {
      return mSpacing;
    }

    /**
      Is Spacing Immutable
    */
    bool isSpacingImmutable() const
    {
      return isImmutable( QStringLiteral( "Spacing" ) );
    }

    /**
      Get Item object corresponding to Spacing()
    */
    ItemInt *spacingItem()
    {
      return mSpacingItem;
    }

    /**
      Set Margin
    */
    void setMargin( int v )
    {
      if (!isMarginImmutable())
        mMargin = v;
    }

    /**
      Get Margin
    */
    int margin() const
    {
      return mMargin;
    }

    /**
      Is Margin Immutable
    */
    bool isMarginImmutable() const
    {
      return isImmutable( QStringLiteral( "Margin" ) );
    }

    /**
      Get Item object corresponding to Margin()
    */
    ItemInt *marginItem()
    {
      return mMarginItem;
    }

    /**
      Set BackgroundImage
    */
    void setBackgroundImage( const QUrl & v )
    {
      if (!isBackgroundImageImmutable())
        mBackgroundImage = v;
    }

    /**
      Get BackgroundImage
    */
    QUrl backgroundImage() const
    {
      return mBackgroundImage;
    }

    /**
      Is BackgroundImage Immutable
    */
    bool isBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "BackgroundImage" ) );
    }

    /**
      Get Item object corresponding to BackgroundImage()
    */
    ItemUrl *backgroundImageItem()
    {
      return mBackgroundImageItem;
    }

    /**
      Set IrcColorCode$(colorNumber)
    */
    void setIrcColorCode( uint i, const QColor & v )
    {
      if (!isIrcColorCodeImmutable( i ))
        mIrcColorCode[i] = v;
    }

    /**
      Get IrcColorCode$(colorNumber)
    */
    QColor ircColorCode( uint i ) const
    {
      return mIrcColorCode[i];
    }

    /**
      Is IrcColorCode$(colorNumber) Immutable
    */
    bool isIrcColorCodeImmutable( uint i ) const
    {
      return isImmutable( QStringLiteral( "IrcColorCode%1" ).arg( i ) );
    }

    /**
      Get Item object corresponding to IrcColorCode()
    */
    ItemColor *ircColorCodeItem( uint i )
    {
      return mIrcColorCodeItem[i];
    }

    /**
      Set AllowColorCodes
    */
    void setAllowColorCodes( bool v )
    {
      if (!isAllowColorCodesImmutable())
        mAllowColorCodes = v;
    }

    /**
      Get AllowColorCodes
    */
    bool allowColorCodes() const
    {
      return mAllowColorCodes;
    }

    /**
      Is AllowColorCodes Immutable
    */
    bool isAllowColorCodesImmutable() const
    {
      return isImmutable( QStringLiteral( "AllowColorCodes" ) );
    }

    /**
      Get Item object corresponding to AllowColorCodes()
    */
    ItemBool *allowColorCodesItem()
    {
      return mAllowColorCodesItem;
    }

    /**
      Set NickColor$(nickNumber)
    */
    void setNickColor( uint i, const QColor & v )
    {
      if (!isNickColorImmutable( i ))
        mNickColor[i] = v;
    }

    /**
      Get NickColor$(nickNumber)
    */
    QColor nickColor( uint i ) const
    {
      return mNickColor[i];
    }

    /**
      Is NickColor$(nickNumber) Immutable
    */
    bool isNickColorImmutable( uint i ) const
    {
      return isImmutable( QStringLiteral( "NickColor%1" ).arg( i ) );
    }

    /**
      Get Item object corresponding to NickColor()
    */
    ItemColor *nickColorItem( uint i )
    {
      return mNickColorItem[i];
    }

    /**
      Set UseColoredNicks
    */
    void setUseColoredNicks( bool v )
    {
      if (!isUseColoredNicksImmutable())
        mUseColoredNicks = v;
    }

    /**
      Get UseColoredNicks
    */
    bool useColoredNicks() const
    {
      return mUseColoredNicks;
    }

    /**
      Is UseColoredNicks Immutable
    */
    bool isUseColoredNicksImmutable() const
    {
      return isImmutable( QStringLiteral( "UseColoredNicks" ) );
    }

    /**
      Get Item object corresponding to UseColoredNicks()
    */
    ItemBool *useColoredNicksItem()
    {
      return mUseColoredNicksItem;
    }

    /**
      Set ShowTabBarCloseButton
    */
    void setShowTabBarCloseButton( bool v )
    {
      if (!isShowTabBarCloseButtonImmutable())
        mShowTabBarCloseButton = v;
    }

    /**
      Get ShowTabBarCloseButton
    */
    bool showTabBarCloseButton() const
    {
      return mShowTabBarCloseButton;
    }

    /**
      Is ShowTabBarCloseButton Immutable
    */
    bool isShowTabBarCloseButtonImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowTabBarCloseButton" ) );
    }

    /**
      Get Item object corresponding to ShowTabBarCloseButton()
    */
    ItemBool *showTabBarCloseButtonItem()
    {
      return mShowTabBarCloseButtonItem;
    }

    /**
      Set ShowTopic
    */
    void setShowTopic( bool v )
    {
      if (!isShowTopicImmutable())
        mShowTopic = v;
    }

    /**
      Get ShowTopic
    */
    bool showTopic() const
    {
      return mShowTopic;
    }

    /**
      Is ShowTopic Immutable
    */
    bool isShowTopicImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowTopic" ) );
    }

    /**
      Get Item object corresponding to ShowTopic()
    */
    ItemBool *showTopicItem()
    {
      return mShowTopicItem;
    }

    /**
      Set ShowNicknameBox
    */
    void setShowNicknameBox( bool v )
    {
      if (!isShowNicknameBoxImmutable())
        mShowNicknameBox = v;
    }

    /**
      Get ShowNicknameBox
    */
    bool showNicknameBox() const
    {
      return mShowNicknameBox;
    }

    /**
      Is ShowNicknameBox Immutable
    */
    bool isShowNicknameBoxImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowNicknameBox" ) );
    }

    /**
      Get Item object corresponding to ShowNicknameBox()
    */
    ItemBool *showNicknameBoxItem()
    {
      return mShowNicknameBoxItem;
    }

    /**
      Set UseBoldNicks
    */
    void setUseBoldNicks( bool v )
    {
      if (!isUseBoldNicksImmutable())
        mUseBoldNicks = v;
    }

    /**
      Get UseBoldNicks
    */
    bool useBoldNicks() const
    {
      return mUseBoldNicks;
    }

    /**
      Is UseBoldNicks Immutable
    */
    bool isUseBoldNicksImmutable() const
    {
      return isImmutable( QStringLiteral( "UseBoldNicks" ) );
    }

    /**
      Get Item object corresponding to UseBoldNicks()
    */
    ItemBool *useBoldNicksItem()
    {
      return mUseBoldNicksItem;
    }

    /**
      Set UseLiteralModes
    */
    void setUseLiteralModes( bool v )
    {
      if (!isUseLiteralModesImmutable())
        mUseLiteralModes = v;
    }

    /**
      Get UseLiteralModes
    */
    bool useLiteralModes() const
    {
      return mUseLiteralModes;
    }

    /**
      Is UseLiteralModes Immutable
    */
    bool isUseLiteralModesImmutable() const
    {
      return isImmutable( QStringLiteral( "UseLiteralModes" ) );
    }

    /**
      Get Item object corresponding to UseLiteralModes()
    */
    ItemBool *useLiteralModesItem()
    {
      return mUseLiteralModesItem;
    }

    /**
      Set FocusNewQueries
    */
    void setFocusNewQueries( bool v )
    {
      if (!isFocusNewQueriesImmutable())
        mFocusNewQueries = v;
    }

    /**
      Get FocusNewQueries
    */
    bool focusNewQueries() const
    {
      return mFocusNewQueries;
    }

    /**
      Is FocusNewQueries Immutable
    */
    bool isFocusNewQueriesImmutable() const
    {
      return isImmutable( QStringLiteral( "FocusNewQueries" ) );
    }

    /**
      Get Item object corresponding to FocusNewQueries()
    */
    ItemBool *focusNewQueriesItem()
    {
      return mFocusNewQueriesItem;
    }

    /**
      Set Hide the scrollbar
    */
    void setShowIRCViewScrollBar( bool v )
    {
      if (!isShowIRCViewScrollBarImmutable())
        mShowIRCViewScrollBar = v;
    }

    /**
      Get Hide the scrollbar
    */
    bool showIRCViewScrollBar() const
    {
      return mShowIRCViewScrollBar;
    }

    /**
      Is Hide the scrollbar Immutable
    */
    bool isShowIRCViewScrollBarImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowIRCViewScrollBar" ) );
    }

    /**
      Get Item object corresponding to ShowIRCViewScrollBar()
    */
    ItemBool *showIRCViewScrollBarItem()
    {
      return mShowIRCViewScrollBarItem;
    }

    /**
      Set SpellChecking
    */
    void setSpellChecking( bool v )
    {
      if (!isSpellCheckingImmutable())
        mSpellChecking = v;
    }

    /**
      Get SpellChecking
    */
    bool spellChecking() const
    {
      return mSpellChecking;
    }

    /**
      Is SpellChecking Immutable
    */
    bool isSpellCheckingImmutable() const
    {
      return isImmutable( QStringLiteral( "SpellChecking" ) );
    }

    /**
      Get Item object corresponding to SpellChecking()
    */
    ItemBool *spellCheckingItem()
    {
      return mSpellCheckingItem;
    }

    /**
      Set CustomVersionReplyEnabled
    */
    void setCustomVersionReplyEnabled( bool v )
    {
      if (!isCustomVersionReplyEnabledImmutable())
        mCustomVersionReplyEnabled = v;
    }

    /**
      Get CustomVersionReplyEnabled
    */
    bool customVersionReplyEnabled() const
    {
      return mCustomVersionReplyEnabled;
    }

    /**
      Is CustomVersionReplyEnabled Immutable
    */
    bool isCustomVersionReplyEnabledImmutable() const
    {
      return isImmutable( QStringLiteral( "CustomVersionReplyEnabled" ) );
    }

    /**
      Get Item object corresponding to CustomVersionReplyEnabled()
    */
    ItemBool *customVersionReplyEnabledItem()
    {
      return mCustomVersionReplyEnabledItem;
    }

    /**
      Set CustomVersionReply
    */
    void setCustomVersionReply( const QString & v )
    {
      if (!isCustomVersionReplyImmutable())
        mCustomVersionReply = v;
    }

    /**
      Get CustomVersionReply
    */
    QString customVersionReply() const
    {
      return mCustomVersionReply;
    }

    /**
      Is CustomVersionReply Immutable
    */
    bool isCustomVersionReplyImmutable() const
    {
      return isImmutable( QStringLiteral( "CustomVersionReply" ) );
    }

    /**
      Get Item object corresponding to CustomVersionReply()
    */
    ItemString *customVersionReplyItem()
    {
      return mCustomVersionReplyItem;
    }

    /**
      Set UseMultiRowInputBox
    */
    void setUseMultiRowInputBox( bool v )
    {
      if (!isUseMultiRowInputBoxImmutable())
        mUseMultiRowInputBox = v;
    }

    /**
      Get UseMultiRowInputBox
    */
    bool useMultiRowInputBox() const
    {
      return mUseMultiRowInputBox;
    }

    /**
      Is UseMultiRowInputBox Immutable
    */
    bool isUseMultiRowInputBoxImmutable() const
    {
      return isImmutable( QStringLiteral( "UseMultiRowInputBox" ) );
    }

    /**
      Get Item object corresponding to UseMultiRowInputBox()
    */
    ItemBool *useMultiRowInputBoxItem()
    {
      return mUseMultiRowInputBoxItem;
    }

    /**
      Set CommandChar
    */
    void setCommandChar( const QString & v )
    {
      if (!isCommandCharImmutable())
        mCommandChar = v;
    }

    /**
      Get CommandChar
    */
    QString commandChar() const
    {
      return mCommandChar;
    }

    /**
      Is CommandChar Immutable
    */
    bool isCommandCharImmutable() const
    {
      return isImmutable( QStringLiteral( "CommandChar" ) );
    }

    /**
      Get Item object corresponding to CommandChar()
    */
    ItemString *commandCharItem()
    {
      return mCommandCharItem;
    }

    /**
      Set PreShellCommand
    */
    void setPreShellCommand( const QString & v )
    {
      if (!isPreShellCommandImmutable())
        mPreShellCommand = v;
    }

    /**
      Get PreShellCommand
    */
    QString preShellCommand() const
    {
      return mPreShellCommand;
    }

    /**
      Is PreShellCommand Immutable
    */
    bool isPreShellCommandImmutable() const
    {
      return isImmutable( QStringLiteral( "PreShellCommand" ) );
    }

    /**
      Get Item object corresponding to PreShellCommand()
    */
    ItemString *preShellCommandItem()
    {
      return mPreShellCommandItem;
    }

    /**
      Set ShowTrayIcon
    */
    void setShowTrayIcon( bool v )
    {
      if (!isShowTrayIconImmutable())
        mShowTrayIcon = v;
    }

    /**
      Get ShowTrayIcon
    */
    bool showTrayIcon() const
    {
      return mShowTrayIcon;
    }

    /**
      Is ShowTrayIcon Immutable
    */
    bool isShowTrayIconImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowTrayIcon" ) );
    }

    /**
      Get Item object corresponding to ShowTrayIcon()
    */
    ItemBool *showTrayIconItem()
    {
      return mShowTrayIconItem;
    }

    /**
      Set TrayNotify
    */
    void setTrayNotify( bool v )
    {
      if (!isTrayNotifyImmutable())
        mTrayNotify = v;
    }

    /**
      Get TrayNotify
    */
    bool trayNotify() const
    {
      return mTrayNotify;
    }

    /**
      Is TrayNotify Immutable
    */
    bool isTrayNotifyImmutable() const
    {
      return isImmutable( QStringLiteral( "TrayNotify" ) );
    }

    /**
      Get Item object corresponding to TrayNotify()
    */
    ItemBool *trayNotifyItem()
    {
      return mTrayNotifyItem;
    }

    /**
      Set TrayNotifyOnlyOwnNick
    */
    void setTrayNotifyOnlyOwnNick( bool v )
    {
      if (!isTrayNotifyOnlyOwnNickImmutable())
        mTrayNotifyOnlyOwnNick = v;
    }

    /**
      Get TrayNotifyOnlyOwnNick
    */
    bool trayNotifyOnlyOwnNick() const
    {
      return mTrayNotifyOnlyOwnNick;
    }

    /**
      Is TrayNotifyOnlyOwnNick Immutable
    */
    bool isTrayNotifyOnlyOwnNickImmutable() const
    {
      return isImmutable( QStringLiteral( "TrayNotifyOnlyOwnNick" ) );
    }

    /**
      Get Item object corresponding to TrayNotifyOnlyOwnNick()
    */
    ItemBool *trayNotifyOnlyOwnNickItem()
    {
      return mTrayNotifyOnlyOwnNickItem;
    }

    /**
      Set TrayNotifyBlink
    */
    void setTrayNotifyBlink( bool v )
    {
      if (!isTrayNotifyBlinkImmutable())
        mTrayNotifyBlink = v;
    }

    /**
      Get TrayNotifyBlink
    */
    bool trayNotifyBlink() const
    {
      return mTrayNotifyBlink;
    }

    /**
      Is TrayNotifyBlink Immutable
    */
    bool isTrayNotifyBlinkImmutable() const
    {
      return isImmutable( QStringLiteral( "TrayNotifyBlink" ) );
    }

    /**
      Get Item object corresponding to TrayNotifyBlink()
    */
    ItemBool *trayNotifyBlinkItem()
    {
      return mTrayNotifyBlinkItem;
    }

    /**
      Set Start with hidden main window
    */
    void setHideToTrayOnStartup( bool v )
    {
      if (!isHideToTrayOnStartupImmutable())
        mHideToTrayOnStartup = v;
    }

    /**
      Get Start with hidden main window
    */
    bool hideToTrayOnStartup() const
    {
      return mHideToTrayOnStartup;
    }

    /**
      Is Start with hidden main window Immutable
    */
    bool isHideToTrayOnStartupImmutable() const
    {
      return isImmutable( QStringLiteral( "HideToTrayOnStartup" ) );
    }

    /**
      Get Item object corresponding to HideToTrayOnStartup()
    */
    ItemBool *hideToTrayOnStartupItem()
    {
      return mHideToTrayOnStartupItem;
    }

    /**
      Set TrayActivateNoWindow
    */
    void setTrayActivateNoWindow( bool v )
    {
      if (!isTrayActivateNoWindowImmutable())
        mTrayActivateNoWindow = v;
    }

    /**
      Get TrayActivateNoWindow
    */
    bool trayActivateNoWindow() const
    {
      return mTrayActivateNoWindow;
    }

    /**
      Is TrayActivateNoWindow Immutable
    */
    bool isTrayActivateNoWindowImmutable() const
    {
      return isImmutable( QStringLiteral( "TrayActivateNoWindow" ) );
    }

    /**
      Get Item object corresponding to TrayActivateNoWindow()
    */
    ItemBool *trayActivateNoWindowItem()
    {
      return mTrayActivateNoWindowItem;
    }

    /**
      Set ShowBackgroundImage
    */
    void setShowBackgroundImage( bool v )
    {
      if (!isShowBackgroundImageImmutable())
        mShowBackgroundImage = v;
    }

    /**
      Get ShowBackgroundImage
    */
    bool showBackgroundImage() const
    {
      return mShowBackgroundImage;
    }

    /**
      Is ShowBackgroundImage Immutable
    */
    bool isShowBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to ShowBackgroundImage()
    */
    ItemBool *showBackgroundImageItem()
    {
      return mShowBackgroundImageItem;
    }

    /**
      Set MultilineEditGeometry
    */
    void setMultilineEditSize( const QSize & v )
    {
      if (!isMultilineEditSizeImmutable())
        mMultilineEditSize = v;
    }

    /**
      Get MultilineEditGeometry
    */
    QSize multilineEditSize() const
    {
      return mMultilineEditSize;
    }

    /**
      Is MultilineEditGeometry Immutable
    */
    bool isMultilineEditSizeImmutable() const
    {
      return isImmutable( QStringLiteral( "MultilineEditSize" ) );
    }

    /**
      Get Item object corresponding to MultilineEditSize()
    */
    ItemSize *multilineEditSizeItem()
    {
      return mMultilineEditSizeItem;
    }

    /**
      Set LogfileBufferSize
    */
    void setLogfileBufferSize( int v )
    {
      if (!isLogfileBufferSizeImmutable())
        mLogfileBufferSize = v;
    }

    /**
      Get LogfileBufferSize
    */
    int logfileBufferSize() const
    {
      return mLogfileBufferSize;
    }

    /**
      Is LogfileBufferSize Immutable
    */
    bool isLogfileBufferSizeImmutable() const
    {
      return isImmutable( QStringLiteral( "LogfileBufferSize" ) );
    }

    /**
      Get Item object corresponding to LogfileBufferSize()
    */
    ItemInt *logfileBufferSizeItem()
    {
      return mLogfileBufferSizeItem;
    }

    /**
      Set ScrollbackMax
    */
    void setScrollbackMax( int v )
    {
      if (!isScrollbackMaxImmutable())
        mScrollbackMax = v;
    }

    /**
      Get ScrollbackMax
    */
    int scrollbackMax() const
    {
      return mScrollbackMax;
    }

    /**
      Is ScrollbackMax Immutable
    */
    bool isScrollbackMaxImmutable() const
    {
      return isImmutable( QStringLiteral( "ScrollbackMax" ) );
    }

    /**
      Get Item object corresponding to ScrollbackMax()
    */
    ItemInt *scrollbackMaxItem()
    {
      return mScrollbackMaxItem;
    }

    /**
      Set AutoWhoNicksLimit
    */
    void setAutoWhoNicksLimit( int v )
    {
      if (!isAutoWhoNicksLimitImmutable())
        mAutoWhoNicksLimit = v;
    }

    /**
      Get AutoWhoNicksLimit
    */
    int autoWhoNicksLimit() const
    {
      return mAutoWhoNicksLimit;
    }

    /**
      Is AutoWhoNicksLimit Immutable
    */
    bool isAutoWhoNicksLimitImmutable() const
    {
      return isImmutable( QStringLiteral( "AutoWhoNicksLimit" ) );
    }

    /**
      Get Item object corresponding to AutoWhoNicksLimit()
    */
    ItemInt *autoWhoNicksLimitItem()
    {
      return mAutoWhoNicksLimitItem;
    }

    /**
      Set AutoWhoContinuousEnabled
    */
    void setAutoWhoContinuousEnabled( bool v )
    {
      if (!isAutoWhoContinuousEnabledImmutable())
        mAutoWhoContinuousEnabled = v;
    }

    /**
      Get AutoWhoContinuousEnabled
    */
    bool autoWhoContinuousEnabled() const
    {
      return mAutoWhoContinuousEnabled;
    }

    /**
      Is AutoWhoContinuousEnabled Immutable
    */
    bool isAutoWhoContinuousEnabledImmutable() const
    {
      return isImmutable( QStringLiteral( "AutoWhoContinuousEnabled" ) );
    }

    /**
      Get Item object corresponding to AutoWhoContinuousEnabled()
    */
    ItemBool *autoWhoContinuousEnabledItem()
    {
      return mAutoWhoContinuousEnabledItem;
    }

    /**
      Set AutoWhoContinuousInterval
    */
    void setAutoWhoContinuousInterval( int v )
    {
      if (!isAutoWhoContinuousIntervalImmutable())
        mAutoWhoContinuousInterval = v;
    }

    /**
      Get AutoWhoContinuousInterval
    */
    int autoWhoContinuousInterval() const
    {
      return mAutoWhoContinuousInterval;
    }

    /**
      Is AutoWhoContinuousInterval Immutable
    */
    bool isAutoWhoContinuousIntervalImmutable() const
    {
      return isImmutable( QStringLiteral( "AutoWhoContinuousInterval" ) );
    }

    /**
      Get Item object corresponding to AutoWhoContinuousInterval()
    */
    ItemInt *autoWhoContinuousIntervalItem()
    {
      return mAutoWhoContinuousIntervalItem;
    }

    /**
      Set &Show real names next to nicknames
    */
    void setShowRealNames( bool v )
    {
      if (!isShowRealNamesImmutable())
        mShowRealNames = v;
    }

    /**
      Get &Show real names next to nicknames
    */
    bool showRealNames() const
    {
      return mShowRealNames;
    }

    /**
      Is &Show real names next to nicknames Immutable
    */
    bool isShowRealNamesImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowRealNames" ) );
    }

    /**
      Get Item object corresponding to ShowRealNames()
    */
    ItemBool *showRealNamesItem()
    {
      return mShowRealNamesItem;
    }

    /**
      Set ChannelDoubleClickAction
    */
    void setChannelDoubleClickAction( const QString & v )
    {
      if (!isChannelDoubleClickActionImmutable())
        mChannelDoubleClickAction = v;
    }

    /**
      Get ChannelDoubleClickAction
    */
    QString channelDoubleClickAction() const
    {
      return mChannelDoubleClickAction;
    }

    /**
      Is ChannelDoubleClickAction Immutable
    */
    bool isChannelDoubleClickActionImmutable() const
    {
      return isImmutable( QStringLiteral( "ChannelDoubleClickAction" ) );
    }

    /**
      Get Item object corresponding to ChannelDoubleClickAction()
    */
    ItemString *channelDoubleClickActionItem()
    {
      return mChannelDoubleClickActionItem;
    }

    /**
      Set NotifyDoubleClickAction
    */
    void setNotifyDoubleClickAction( const QString & v )
    {
      if (!isNotifyDoubleClickActionImmutable())
        mNotifyDoubleClickAction = v;
    }

    /**
      Get NotifyDoubleClickAction
    */
    QString notifyDoubleClickAction() const
    {
      return mNotifyDoubleClickAction;
    }

    /**
      Is NotifyDoubleClickAction Immutable
    */
    bool isNotifyDoubleClickActionImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyDoubleClickAction" ) );
    }

    /**
      Get Item object corresponding to NotifyDoubleClickAction()
    */
    ItemString *notifyDoubleClickActionItem()
    {
      return mNotifyDoubleClickActionItem;
    }

    /**
      Set Beep
    */
    void setBeep( bool v )
    {
      if (!isBeepImmutable())
        mBeep = v;
    }

    /**
      Get Beep
    */
    bool beep() const
    {
      return mBeep;
    }

    /**
      Is Beep Immutable
    */
    bool isBeepImmutable() const
    {
      return isImmutable( QStringLiteral( "Beep" ) );
    }

    /**
      Get Item object corresponding to Beep()
    */
    ItemBool *beepItem()
    {
      return mBeepItem;
    }

    /**
      Set RawLog
    */
    void setRawLog( bool v )
    {
      if (!isRawLogImmutable())
        mRawLog = v;
    }

    /**
      Get RawLog
    */
    bool rawLog() const
    {
      return mRawLog;
    }

    /**
      Is RawLog Immutable
    */
    bool isRawLogImmutable() const
    {
      return isImmutable( QStringLiteral( "RawLog" ) );
    }

    /**
      Get Item object corresponding to RawLog()
    */
    ItemBool *rawLogItem()
    {
      return mRawLogItem;
    }

    /**
      Set VersionReply
    */
    void setVersionReply( const QString & v )
    {
      if (!isVersionReplyImmutable())
        mVersionReply = v;
    }

    /**
      Get VersionReply
    */
    QString versionReply() const
    {
      return mVersionReply;
    }

    /**
      Is VersionReply Immutable
    */
    bool isVersionReplyImmutable() const
    {
      return isImmutable( QStringLiteral( "VersionReply" ) );
    }

    /**
      Get Item object corresponding to VersionReply()
    */
    ItemString *versionReplyItem()
    {
      return mVersionReplyItem;
    }

    /**
      Set MaximumLag
    */
    void setMaximumLagTime( int v )
    {
      if (!isMaximumLagTimeImmutable())
        mMaximumLagTime = v;
    }

    /**
      Get MaximumLag
    */
    int maximumLagTime() const
    {
      return mMaximumLagTime;
    }

    /**
      Is MaximumLag Immutable
    */
    bool isMaximumLagTimeImmutable() const
    {
      return isImmutable( QStringLiteral( "MaximumLagTime" ) );
    }

    /**
      Get Item object corresponding to MaximumLagTime()
    */
    ItemInt *maximumLagTimeItem()
    {
      return mMaximumLagTimeItem;
    }

    /**
      Set RedirectServerAndAppMsgToStatusPane
    */
    void setRedirectServerAndAppMsgToStatusPane( bool v )
    {
      if (!isRedirectServerAndAppMsgToStatusPaneImmutable())
        mRedirectServerAndAppMsgToStatusPane = v;
    }

    /**
      Get RedirectServerAndAppMsgToStatusPane
    */
    bool redirectServerAndAppMsgToStatusPane() const
    {
      return mRedirectServerAndAppMsgToStatusPane;
    }

    /**
      Is RedirectServerAndAppMsgToStatusPane Immutable
    */
    bool isRedirectServerAndAppMsgToStatusPaneImmutable() const
    {
      return isImmutable( QStringLiteral( "RedirectServerAndAppMsgToStatusPane" ) );
    }

    /**
      Get Item object corresponding to RedirectServerAndAppMsgToStatusPane()
    */
    ItemBool *redirectServerAndAppMsgToStatusPaneItem()
    {
      return mRedirectServerAndAppMsgToStatusPaneItem;
    }

    /**
      Set DisableNotifyWhileAway
    */
    void setDisableNotifyWhileAway( bool v )
    {
      if (!isDisableNotifyWhileAwayImmutable())
        mDisableNotifyWhileAway = v;
    }

    /**
      Get DisableNotifyWhileAway
    */
    bool disableNotifyWhileAway() const
    {
      return mDisableNotifyWhileAway;
    }

    /**
      Is DisableNotifyWhileAway Immutable
    */
    bool isDisableNotifyWhileAwayImmutable() const
    {
      return isImmutable( QStringLiteral( "DisableNotifyWhileAway" ) );
    }

    /**
      Get Item object corresponding to DisableNotifyWhileAway()
    */
    ItemBool *disableNotifyWhileAwayItem()
    {
      return mDisableNotifyWhileAwayItem;
    }

    /**
      Set AutoAwayPollInterval
    */
    void setAutoAwayPollInterval( int v )
    {
      if (v < 10)
      {
        qDebug() << "setAutoAwayPollInterval: value " << v << " is less than the minimum value of 10";
        v = 10;
      }
      if (!isAutoAwayPollIntervalImmutable())
        mAutoAwayPollInterval = v;
    }

    /**
      Get AutoAwayPollInterval
    */
    int autoAwayPollInterval() const
    {
      return mAutoAwayPollInterval;
    }

    /**
      Is AutoAwayPollInterval Immutable
    */
    bool isAutoAwayPollIntervalImmutable() const
    {
      return isImmutable( QStringLiteral( "AutoAwayPollInterval" ) );
    }

    /**
      Get Item object corresponding to AutoAwayPollInterval()
    */
    ItemInt *autoAwayPollIntervalItem()
    {
      return mAutoAwayPollIntervalItem;
    }

    /**
      Set AutomaticRememberLine
    */
    void setAutomaticRememberLine( bool v )
    {
      if (!isAutomaticRememberLineImmutable())
        mAutomaticRememberLine = v;
    }

    /**
      Get AutomaticRememberLine
    */
    bool automaticRememberLine() const
    {
      return mAutomaticRememberLine;
    }

    /**
      Is AutomaticRememberLine Immutable
    */
    bool isAutomaticRememberLineImmutable() const
    {
      return isImmutable( QStringLiteral( "AutomaticRememberLine" ) );
    }

    /**
      Get Item object corresponding to AutomaticRememberLine()
    */
    ItemBool *automaticRememberLineItem()
    {
      return mAutomaticRememberLineItem;
    }

    /**
      Set AutomaticRememberLineOnlyOnTextChange
    */
    void setAutomaticRememberLineOnlyOnTextChange( bool v )
    {
      if (!isAutomaticRememberLineOnlyOnTextChangeImmutable())
        mAutomaticRememberLineOnlyOnTextChange = v;
    }

    /**
      Get AutomaticRememberLineOnlyOnTextChange
    */
    bool automaticRememberLineOnlyOnTextChange() const
    {
      return mAutomaticRememberLineOnlyOnTextChange;
    }

    /**
      Is AutomaticRememberLineOnlyOnTextChange Immutable
    */
    bool isAutomaticRememberLineOnlyOnTextChangeImmutable() const
    {
      return isImmutable( QStringLiteral( "AutomaticRememberLineOnlyOnTextChange" ) );
    }

    /**
      Get Item object corresponding to AutomaticRememberLineOnlyOnTextChange()
    */
    ItemBool *automaticRememberLineOnlyOnTextChangeItem()
    {
      return mAutomaticRememberLineOnlyOnTextChangeItem;
    }

    /**
      Set MarkerLineInAllViews
    */
    void setMarkerLineInAllViews( bool v )
    {
      if (!isMarkerLineInAllViewsImmutable())
        mMarkerLineInAllViews = v;
    }

    /**
      Get MarkerLineInAllViews
    */
    bool markerLineInAllViews() const
    {
      return mMarkerLineInAllViews;
    }

    /**
      Is MarkerLineInAllViews Immutable
    */
    bool isMarkerLineInAllViewsImmutable() const
    {
      return isImmutable( QStringLiteral( "MarkerLineInAllViews" ) );
    }

    /**
      Get Item object corresponding to MarkerLineInAllViews()
    */
    ItemBool *markerLineInAllViewsItem()
    {
      return mMarkerLineInAllViewsItem;
    }

    /**
      Set SortByStatus
    */
    void setSortByStatus( bool v )
    {
      if (!isSortByStatusImmutable())
        mSortByStatus = v;
    }

    /**
      Get SortByStatus
    */
    bool sortByStatus() const
    {
      return mSortByStatus;
    }

    /**
      Is SortByStatus Immutable
    */
    bool isSortByStatusImmutable() const
    {
      return isImmutable( QStringLiteral( "SortByStatus" ) );
    }

    /**
      Get Item object corresponding to SortByStatus()
    */
    ItemBool *sortByStatusItem()
    {
      return mSortByStatusItem;
    }

    /**
      Set SortByActivity
    */
    void setSortByActivity( bool v )
    {
      if (!isSortByActivityImmutable())
        mSortByActivity = v;
    }

    /**
      Get SortByActivity
    */
    bool sortByActivity() const
    {
      return mSortByActivity;
    }

    /**
      Is SortByActivity Immutable
    */
    bool isSortByActivityImmutable() const
    {
      return isImmutable( QStringLiteral( "SortByActivity" ) );
    }

    /**
      Get Item object corresponding to SortByActivity()
    */
    ItemBool *sortByActivityItem()
    {
      return mSortByActivityItem;
    }

    /**
      Set SortCaseInsensitive
    */
    void setSortCaseInsensitive( bool v )
    {
      if (!isSortCaseInsensitiveImmutable())
        mSortCaseInsensitive = v;
    }

    /**
      Get SortCaseInsensitive
    */
    bool sortCaseInsensitive() const
    {
      return mSortCaseInsensitive;
    }

    /**
      Is SortCaseInsensitive Immutable
    */
    bool isSortCaseInsensitiveImmutable() const
    {
      return isImmutable( QStringLiteral( "SortCaseInsensitive" ) );
    }

    /**
      Get Item object corresponding to SortCaseInsensitive()
    */
    ItemBool *sortCaseInsensitiveItem()
    {
      return mSortCaseInsensitiveItem;
    }

    /**
      Set LauncherEntryCountMode
    */
    void setLauncherEntryCountMode( int v )
    {
      if (!isLauncherEntryCountModeImmutable())
        mLauncherEntryCountMode = v;
    }

    /**
      Get LauncherEntryCountMode
    */
    int launcherEntryCountMode() const
    {
      return mLauncherEntryCountMode;
    }

    /**
      Is LauncherEntryCountMode Immutable
    */
    bool isLauncherEntryCountModeImmutable() const
    {
      return isImmutable( QStringLiteral( "LauncherEntryCountMode" ) );
    }

    /**
      Get Item object corresponding to LauncherEntryCountMode()
    */
    ItemEnum *launcherEntryCountModeItem()
    {
      return mLauncherEntryCountModeItem;
    }

    /**
      Set LauncherEntryCountUseNick
    */
    void setLauncherEntryCountUseNick( bool v )
    {
      if (!isLauncherEntryCountUseNickImmutable())
        mLauncherEntryCountUseNick = v;
    }

    /**
      Get LauncherEntryCountUseNick
    */
    bool launcherEntryCountUseNick() const
    {
      return mLauncherEntryCountUseNick;
    }

    /**
      Is LauncherEntryCountUseNick Immutable
    */
    bool isLauncherEntryCountUseNickImmutable() const
    {
      return isImmutable( QStringLiteral( "LauncherEntryCountUseNick" ) );
    }

    /**
      Get Item object corresponding to LauncherEntryCountUseNick()
    */
    ItemBool *launcherEntryCountUseNickItem()
    {
      return mLauncherEntryCountUseNickItem;
    }

    /**
      Set LauncherEntryCountUseHighlights
    */
    void setLauncherEntryCountUseHighlights( bool v )
    {
      if (!isLauncherEntryCountUseHighlightsImmutable())
        mLauncherEntryCountUseHighlights = v;
    }

    /**
      Get LauncherEntryCountUseHighlights
    */
    bool launcherEntryCountUseHighlights() const
    {
      return mLauncherEntryCountUseHighlights;
    }

    /**
      Is LauncherEntryCountUseHighlights Immutable
    */
    bool isLauncherEntryCountUseHighlightsImmutable() const
    {
      return isImmutable( QStringLiteral( "LauncherEntryCountUseHighlights" ) );
    }

    /**
      Get Item object corresponding to LauncherEntryCountUseHighlights()
    */
    ItemBool *launcherEntryCountUseHighlightsItem()
    {
      return mLauncherEntryCountUseHighlightsItem;
    }

    /**
      Set LauncherEntryCountUsePrivate
    */
    void setLauncherEntryCountUsePrivate( bool v )
    {
      if (!isLauncherEntryCountUsePrivateImmutable())
        mLauncherEntryCountUsePrivate = v;
    }

    /**
      Get LauncherEntryCountUsePrivate
    */
    bool launcherEntryCountUsePrivate() const
    {
      return mLauncherEntryCountUsePrivate;
    }

    /**
      Is LauncherEntryCountUsePrivate Immutable
    */
    bool isLauncherEntryCountUsePrivateImmutable() const
    {
      return isImmutable( QStringLiteral( "LauncherEntryCountUsePrivate" ) );
    }

    /**
      Get Item object corresponding to LauncherEntryCountUsePrivate()
    */
    ItemBool *launcherEntryCountUsePrivateItem()
    {
      return mLauncherEntryCountUsePrivateItem;
    }

    /**
      Set LauncherEntryCountUseMsgs
    */
    void setLauncherEntryCountUseMsgs( bool v )
    {
      if (!isLauncherEntryCountUseMsgsImmutable())
        mLauncherEntryCountUseMsgs = v;
    }

    /**
      Get LauncherEntryCountUseMsgs
    */
    bool launcherEntryCountUseMsgs() const
    {
      return mLauncherEntryCountUseMsgs;
    }

    /**
      Is LauncherEntryCountUseMsgs Immutable
    */
    bool isLauncherEntryCountUseMsgsImmutable() const
    {
      return isImmutable( QStringLiteral( "LauncherEntryCountUseMsgs" ) );
    }

    /**
      Get Item object corresponding to LauncherEntryCountUseMsgs()
    */
    ItemBool *launcherEntryCountUseMsgsItem()
    {
      return mLauncherEntryCountUseMsgsItem;
    }

    /**
      Set LauncherEntryCountUseSystem
    */
    void setLauncherEntryCountUseSystem( bool v )
    {
      if (!isLauncherEntryCountUseSystemImmutable())
        mLauncherEntryCountUseSystem = v;
    }

    /**
      Get LauncherEntryCountUseSystem
    */
    bool launcherEntryCountUseSystem() const
    {
      return mLauncherEntryCountUseSystem;
    }

    /**
      Is LauncherEntryCountUseSystem Immutable
    */
    bool isLauncherEntryCountUseSystemImmutable() const
    {
      return isImmutable( QStringLiteral( "LauncherEntryCountUseSystem" ) );
    }

    /**
      Get Item object corresponding to LauncherEntryCountUseSystem()
    */
    ItemBool *launcherEntryCountUseSystemItem()
    {
      return mLauncherEntryCountUseSystemItem;
    }

    /**
      Set LauncherEntryCountUseChannelEvents
    */
    void setLauncherEntryCountUseChannelEvents( bool v )
    {
      if (!isLauncherEntryCountUseChannelEventsImmutable())
        mLauncherEntryCountUseChannelEvents = v;
    }

    /**
      Get LauncherEntryCountUseChannelEvents
    */
    bool launcherEntryCountUseChannelEvents() const
    {
      return mLauncherEntryCountUseChannelEvents;
    }

    /**
      Is LauncherEntryCountUseChannelEvents Immutable
    */
    bool isLauncherEntryCountUseChannelEventsImmutable() const
    {
      return isImmutable( QStringLiteral( "LauncherEntryCountUseChannelEvents" ) );
    }

    /**
      Get Item object corresponding to LauncherEntryCountUseChannelEvents()
    */
    ItemBool *launcherEntryCountUseChannelEventsItem()
    {
      return mLauncherEntryCountUseChannelEventsItem;
    }

    /**
      Set UseOSD
    */
    void setUseOSD( bool v )
    {
      if (!isUseOSDImmutable())
        mUseOSD = v;
    }

    /**
      Get UseOSD
    */
    bool useOSD() const
    {
      return mUseOSD;
    }

    /**
      Is UseOSD Immutable
    */
    bool isUseOSDImmutable() const
    {
      return isImmutable( QStringLiteral( "UseOSD" ) );
    }

    /**
      Get Item object corresponding to UseOSD()
    */
    ItemBool *useOSDItem()
    {
      return mUseOSDItem;
    }

    /**
      Set ShowOwnNick
    */
    void setOSDShowOwnNick( bool v )
    {
      if (!isOSDShowOwnNickImmutable())
        mOSDShowOwnNick = v;
    }

    /**
      Get ShowOwnNick
    */
    bool oSDShowOwnNick() const
    {
      return mOSDShowOwnNick;
    }

    /**
      Is ShowOwnNick Immutable
    */
    bool isOSDShowOwnNickImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDShowOwnNick" ) );
    }

    /**
      Get Item object corresponding to OSDShowOwnNick()
    */
    ItemBool *oSDShowOwnNickItem()
    {
      return mOSDShowOwnNickItem;
    }

    /**
      Set ShowChannel
    */
    void setOSDShowChannel( bool v )
    {
      if (!isOSDShowChannelImmutable())
        mOSDShowChannel = v;
    }

    /**
      Get ShowChannel
    */
    bool oSDShowChannel() const
    {
      return mOSDShowChannel;
    }

    /**
      Is ShowChannel Immutable
    */
    bool isOSDShowChannelImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDShowChannel" ) );
    }

    /**
      Get Item object corresponding to OSDShowChannel()
    */
    ItemBool *oSDShowChannelItem()
    {
      return mOSDShowChannelItem;
    }

    /**
      Set ShowQuery
    */
    void setOSDShowQuery( bool v )
    {
      if (!isOSDShowQueryImmutable())
        mOSDShowQuery = v;
    }

    /**
      Get ShowQuery
    */
    bool oSDShowQuery() const
    {
      return mOSDShowQuery;
    }

    /**
      Is ShowQuery Immutable
    */
    bool isOSDShowQueryImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDShowQuery" ) );
    }

    /**
      Get Item object corresponding to OSDShowQuery()
    */
    ItemBool *oSDShowQueryItem()
    {
      return mOSDShowQueryItem;
    }

    /**
      Set ShowChannelEvent
    */
    void setOSDShowChannelEvent( bool v )
    {
      if (!isOSDShowChannelEventImmutable())
        mOSDShowChannelEvent = v;
    }

    /**
      Get ShowChannelEvent
    */
    bool oSDShowChannelEvent() const
    {
      return mOSDShowChannelEvent;
    }

    /**
      Is ShowChannelEvent Immutable
    */
    bool isOSDShowChannelEventImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDShowChannelEvent" ) );
    }

    /**
      Get Item object corresponding to OSDShowChannelEvent()
    */
    ItemBool *oSDShowChannelEventItem()
    {
      return mOSDShowChannelEventItem;
    }

    /**
      Set OSDFont
    */
    void setOSDFont( const QFont & v )
    {
      if (!isOSDFontImmutable())
        mOSDFont = v;
    }

    /**
      Get OSDFont
    */
    QFont oSDFont() const
    {
      return mOSDFont;
    }

    /**
      Is OSDFont Immutable
    */
    bool isOSDFontImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDFont" ) );
    }

    /**
      Get Item object corresponding to OSDFont()
    */
    ItemFont *oSDFontItem()
    {
      return mOSDFontItem;
    }

    /**
      Set OSDUseCustomColors
    */
    void setOSDUseCustomColors( bool v )
    {
      if (!isOSDUseCustomColorsImmutable())
        mOSDUseCustomColors = v;
    }

    /**
      Get OSDUseCustomColors
    */
    bool oSDUseCustomColors() const
    {
      return mOSDUseCustomColors;
    }

    /**
      Is OSDUseCustomColors Immutable
    */
    bool isOSDUseCustomColorsImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDUseCustomColors" ) );
    }

    /**
      Get Item object corresponding to OSDUseCustomColors()
    */
    ItemBool *oSDUseCustomColorsItem()
    {
      return mOSDUseCustomColorsItem;
    }

    /**
      Set OSDDuration
    */
    void setOSDDuration( int v )
    {
      if (!isOSDDurationImmutable())
        mOSDDuration = v;
    }

    /**
      Get OSDDuration
    */
    int oSDDuration() const
    {
      return mOSDDuration;
    }

    /**
      Is OSDDuration Immutable
    */
    bool isOSDDurationImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDDuration" ) );
    }

    /**
      Get Item object corresponding to OSDDuration()
    */
    ItemInt *oSDDurationItem()
    {
      return mOSDDurationItem;
    }

    /**
      Set OSDScreen
    */
    void setOSDScreen( int v )
    {
      if (!isOSDScreenImmutable())
        mOSDScreen = v;
    }

    /**
      Get OSDScreen
    */
    int oSDScreen() const
    {
      return mOSDScreen;
    }

    /**
      Is OSDScreen Immutable
    */
    bool isOSDScreenImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDScreen" ) );
    }

    /**
      Get Item object corresponding to OSDScreen()
    */
    ItemInt *oSDScreenItem()
    {
      return mOSDScreenItem;
    }

    /**
      Set OSDDrawShadow
    */
    void setOSDDrawShadow( bool v )
    {
      if (!isOSDDrawShadowImmutable())
        mOSDDrawShadow = v;
    }

    /**
      Get OSDDrawShadow
    */
    bool oSDDrawShadow() const
    {
      return mOSDDrawShadow;
    }

    /**
      Is OSDDrawShadow Immutable
    */
    bool isOSDDrawShadowImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDDrawShadow" ) );
    }

    /**
      Get Item object corresponding to OSDDrawShadow()
    */
    ItemBool *oSDDrawShadowItem()
    {
      return mOSDDrawShadowItem;
    }

    /**
      Set OffsetX
    */
    void setOSDOffsetX( int v )
    {
      if (!isOSDOffsetXImmutable())
        mOSDOffsetX = v;
    }

    /**
      Get OffsetX
    */
    int oSDOffsetX() const
    {
      return mOSDOffsetX;
    }

    /**
      Is OffsetX Immutable
    */
    bool isOSDOffsetXImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDOffsetX" ) );
    }

    /**
      Get Item object corresponding to OSDOffsetX()
    */
    ItemInt *oSDOffsetXItem()
    {
      return mOSDOffsetXItem;
    }

    /**
      Set OffsetY
    */
    void setOSDOffsetY( int v )
    {
      if (!isOSDOffsetYImmutable())
        mOSDOffsetY = v;
    }

    /**
      Get OffsetY
    */
    int oSDOffsetY() const
    {
      return mOSDOffsetY;
    }

    /**
      Is OffsetY Immutable
    */
    bool isOSDOffsetYImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDOffsetY" ) );
    }

    /**
      Get Item object corresponding to OSDOffsetY()
    */
    ItemInt *oSDOffsetYItem()
    {
      return mOSDOffsetYItem;
    }

    /**
      Set Alignment
    */
    void setOSDAlignment( int v )
    {
      if (!isOSDAlignmentImmutable())
        mOSDAlignment = v;
    }

    /**
      Get Alignment
    */
    int oSDAlignment() const
    {
      return mOSDAlignment;
    }

    /**
      Is Alignment Immutable
    */
    bool isOSDAlignmentImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDAlignment" ) );
    }

    /**
      Get Item object corresponding to OSDAlignment()
    */
    ItemInt *oSDAlignmentItem()
    {
      return mOSDAlignmentItem;
    }

    /**
      Set OSDTextColor
    */
    void setOSDTextColor( const QColor & v )
    {
      if (!isOSDTextColorImmutable())
        mOSDTextColor = v;
    }

    /**
      Get OSDTextColor
    */
    QColor oSDTextColor() const
    {
      return mOSDTextColor;
    }

    /**
      Is OSDTextColor Immutable
    */
    bool isOSDTextColorImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDTextColor" ) );
    }

    /**
      Get Item object corresponding to OSDTextColor()
    */
    ItemColor *oSDTextColorItem()
    {
      return mOSDTextColorItem;
    }

    /**
      Set OSDBackgroundColor
    */
    void setOSDBackgroundColor( const QColor & v )
    {
      if (!isOSDBackgroundColorImmutable())
        mOSDBackgroundColor = v;
    }

    /**
      Get OSDBackgroundColor
    */
    QColor oSDBackgroundColor() const
    {
      return mOSDBackgroundColor;
    }

    /**
      Is OSDBackgroundColor Immutable
    */
    bool isOSDBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to OSDBackgroundColor()
    */
    ItemColor *oSDBackgroundColorItem()
    {
      return mOSDBackgroundColorItem;
    }

    /**
      Set OSDCheckDesktopLock
    */
    void setOSDCheckDesktopLock( bool v )
    {
      if (!isOSDCheckDesktopLockImmutable())
        mOSDCheckDesktopLock = v;
    }

    /**
      Get OSDCheckDesktopLock
    */
    bool oSDCheckDesktopLock() const
    {
      return mOSDCheckDesktopLock;
    }

    /**
      Is OSDCheckDesktopLock Immutable
    */
    bool isOSDCheckDesktopLockImmutable() const
    {
      return isImmutable( QStringLiteral( "OSDCheckDesktopLock" ) );
    }

    /**
      Get Item object corresponding to OSDCheckDesktopLock()
    */
    ItemBool *oSDCheckDesktopLockItem()
    {
      return mOSDCheckDesktopLockItem;
    }

    /**
      Set NotifyDelay
    */
    void setNotifyDelay( int v )
    {
      if (!isNotifyDelayImmutable())
        mNotifyDelay = v;
    }

    /**
      Get NotifyDelay
    */
    int notifyDelay() const
    {
      return mNotifyDelay;
    }

    /**
      Is NotifyDelay Immutable
    */
    bool isNotifyDelayImmutable() const
    {
      return isImmutable( QStringLiteral( "NotifyDelay" ) );
    }

    /**
      Get Item object corresponding to NotifyDelay()
    */
    ItemInt *notifyDelayItem()
    {
      return mNotifyDelayItem;
    }

    /**
      Set UseNotify
    */
    void setUseNotify( bool v )
    {
      if (!isUseNotifyImmutable())
        mUseNotify = v;
    }

    /**
      Get UseNotify
    */
    bool useNotify() const
    {
      return mUseNotify;
    }

    /**
      Is UseNotify Immutable
    */
    bool isUseNotifyImmutable() const
    {
      return isImmutable( QStringLiteral( "UseNotify" ) );
    }

    /**
      Get Item object corresponding to UseNotify()
    */
    ItemBool *useNotifyItem()
    {
      return mUseNotifyItem;
    }

    /**
      Set Open Watched Nicks tab at application startup
    */
    void setOpenWatchedNicksAtStartup( bool v )
    {
      if (!isOpenWatchedNicksAtStartupImmutable())
        mOpenWatchedNicksAtStartup = v;
    }

    /**
      Get Open Watched Nicks tab at application startup
    */
    bool openWatchedNicksAtStartup() const
    {
      return mOpenWatchedNicksAtStartup;
    }

    /**
      Is Open Watched Nicks tab at application startup Immutable
    */
    bool isOpenWatchedNicksAtStartupImmutable() const
    {
      return isImmutable( QStringLiteral( "OpenWatchedNicksAtStartup" ) );
    }

    /**
      Get Item object corresponding to OpenWatchedNicksAtStartup()
    */
    ItemBool *openWatchedNicksAtStartupItem()
    {
      return mOpenWatchedNicksAtStartupItem;
    }

    /**
      Set HighlightSoundsEnabled
    */
    void setHighlightSoundsEnabled( bool v )
    {
      if (!isHighlightSoundsEnabledImmutable())
        mHighlightSoundsEnabled = v;
    }

    /**
      Get HighlightSoundsEnabled
    */
    bool highlightSoundsEnabled() const
    {
      return mHighlightSoundsEnabled;
    }

    /**
      Is HighlightSoundsEnabled Immutable
    */
    bool isHighlightSoundsEnabledImmutable() const
    {
      return isImmutable( QStringLiteral( "HighlightSoundsEnabled" ) );
    }

    /**
      Get Item object corresponding to HighlightSoundsEnabled()
    */
    ItemBool *highlightSoundsEnabledItem()
    {
      return mHighlightSoundsEnabledItem;
    }

    /**
      Set HighlightNick
    */
    void setHighlightNick( bool v )
    {
      if (!isHighlightNickImmutable())
        mHighlightNick = v;
    }

    /**
      Get HighlightNick
    */
    bool highlightNick() const
    {
      return mHighlightNick;
    }

    /**
      Is HighlightNick Immutable
    */
    bool isHighlightNickImmutable() const
    {
      return isImmutable( QStringLiteral( "HighlightNick" ) );
    }

    /**
      Get Item object corresponding to HighlightNick()
    */
    ItemBool *highlightNickItem()
    {
      return mHighlightNickItem;
    }

    /**
      Set HighlightNickColor
    */
    void setHighlightNickColor( const QColor & v )
    {
      if (!isHighlightNickColorImmutable())
        mHighlightNickColor = v;
    }

    /**
      Get HighlightNickColor
    */
    QColor highlightNickColor() const
    {
      return mHighlightNickColor;
    }

    /**
      Is HighlightNickColor Immutable
    */
    bool isHighlightNickColorImmutable() const
    {
      return isImmutable( QStringLiteral( "HighlightNickColor" ) );
    }

    /**
      Get Item object corresponding to HighlightNickColor()
    */
    ItemColor *highlightNickColorItem()
    {
      return mHighlightNickColorItem;
    }

    /**
      Set HighlightOwnLines
    */
    void setHighlightOwnLines( bool v )
    {
      if (!isHighlightOwnLinesImmutable())
        mHighlightOwnLines = v;
    }

    /**
      Get HighlightOwnLines
    */
    bool highlightOwnLines() const
    {
      return mHighlightOwnLines;
    }

    /**
      Is HighlightOwnLines Immutable
    */
    bool isHighlightOwnLinesImmutable() const
    {
      return isImmutable( QStringLiteral( "HighlightOwnLines" ) );
    }

    /**
      Get Item object corresponding to HighlightOwnLines()
    */
    ItemBool *highlightOwnLinesItem()
    {
      return mHighlightOwnLinesItem;
    }

    /**
      Set HighlightOwnLinesColor
    */
    void setHighlightOwnLinesColor( const QColor & v )
    {
      if (!isHighlightOwnLinesColorImmutable())
        mHighlightOwnLinesColor = v;
    }

    /**
      Get HighlightOwnLinesColor
    */
    QColor highlightOwnLinesColor() const
    {
      return mHighlightOwnLinesColor;
    }

    /**
      Is HighlightOwnLinesColor Immutable
    */
    bool isHighlightOwnLinesColorImmutable() const
    {
      return isImmutable( QStringLiteral( "HighlightOwnLinesColor" ) );
    }

    /**
      Get Item object corresponding to HighlightOwnLinesColor()
    */
    ItemColor *highlightOwnLinesColorItem()
    {
      return mHighlightOwnLinesColorItem;
    }

    /**
      Set Highlight
    */
    void setHighlight( const QString & v )
    {
      if (!isHighlightImmutable())
        mHighlight = v;
    }

    /**
      Get Highlight
    */
    QString highlight() const
    {
      return mHighlight;
    }

    /**
      Is Highlight Immutable
    */
    bool isHighlightImmutable() const
    {
      return isImmutable( QStringLiteral( "Highlight" ) );
    }

    /**
      Get Item object corresponding to Highlight()
    */
    ItemString *highlightItem()
    {
      return mHighlightItem;
    }

    /**
      Set AliasList
    */
    void setAliasList( const QStringList & v )
    {
      if (!isAliasListImmutable())
        mAliasList = v;
    }

    /**
      Get AliasList
    */
    QStringList aliasList() const
    {
      return mAliasList;
    }

    /**
      Is AliasList Immutable
    */
    bool isAliasListImmutable() const
    {
      return isImmutable( QStringLiteral( "AliasList" ) );
    }

    /**
      Get Item object corresponding to AliasList()
    */
    ItemStringList *aliasListItem()
    {
      return mAliasListItem;
    }

    /**
      Set Mode
    */
    void setNickCompletionMode( int v )
    {
      if (!isNickCompletionModeImmutable())
        mNickCompletionMode = v;
    }

    /**
      Get Mode
    */
    int nickCompletionMode() const
    {
      return mNickCompletionMode;
    }

    /**
      Is Mode Immutable
    */
    bool isNickCompletionModeImmutable() const
    {
      return isImmutable( QStringLiteral( "NickCompletionMode" ) );
    }

    /**
      Get Item object corresponding to NickCompletionMode()
    */
    ItemInt *nickCompletionModeItem()
    {
      return mNickCompletionModeItem;
    }

    /**
      Set SuffixStart
    */
    void setNickCompleteSuffixStart( const QString & v )
    {
      if (!isNickCompleteSuffixStartImmutable())
        mNickCompleteSuffixStart = v;
    }

    /**
      Get SuffixStart
    */
    QString nickCompleteSuffixStart() const
    {
      return mNickCompleteSuffixStart;
    }

    /**
      Is SuffixStart Immutable
    */
    bool isNickCompleteSuffixStartImmutable() const
    {
      return isImmutable( QStringLiteral( "NickCompleteSuffixStart" ) );
    }

    /**
      Get Item object corresponding to NickCompleteSuffixStart()
    */
    ItemString *nickCompleteSuffixStartItem()
    {
      return mNickCompleteSuffixStartItem;
    }

    /**
      Set SuffixMiddle
    */
    void setNickCompleteSuffixMiddle( const QString & v )
    {
      if (!isNickCompleteSuffixMiddleImmutable())
        mNickCompleteSuffixMiddle = v;
    }

    /**
      Get SuffixMiddle
    */
    QString nickCompleteSuffixMiddle() const
    {
      return mNickCompleteSuffixMiddle;
    }

    /**
      Is SuffixMiddle Immutable
    */
    bool isNickCompleteSuffixMiddleImmutable() const
    {
      return isImmutable( QStringLiteral( "NickCompleteSuffixMiddle" ) );
    }

    /**
      Get Item object corresponding to NickCompleteSuffixMiddle()
    */
    ItemString *nickCompleteSuffixMiddleItem()
    {
      return mNickCompleteSuffixMiddleItem;
    }

    /**
      Set PrefixCharacter
    */
    void setPrefixCharacter( const QString & v )
    {
      if (!isPrefixCharacterImmutable())
        mPrefixCharacter = v;
    }

    /**
      Get PrefixCharacter
    */
    QString prefixCharacter() const
    {
      return mPrefixCharacter;
    }

    /**
      Is PrefixCharacter Immutable
    */
    bool isPrefixCharacterImmutable() const
    {
      return isImmutable( QStringLiteral( "PrefixCharacter" ) );
    }

    /**
      Get Item object corresponding to PrefixCharacter()
    */
    ItemString *prefixCharacterItem()
    {
      return mPrefixCharacterItem;
    }

    /**
      Set CaseSensitive
    */
    void setNickCompletionCaseSensitive( bool v )
    {
      if (!isNickCompletionCaseSensitiveImmutable())
        mNickCompletionCaseSensitive = v;
    }

    /**
      Get CaseSensitive
    */
    bool nickCompletionCaseSensitive() const
    {
      return mNickCompletionCaseSensitive;
    }

    /**
      Is CaseSensitive Immutable
    */
    bool isNickCompletionCaseSensitiveImmutable() const
    {
      return isImmutable( QStringLiteral( "NickCompletionCaseSensitive" ) );
    }

    /**
      Get Item object corresponding to NickCompletionCaseSensitive()
    */
    ItemBool *nickCompletionCaseSensitiveItem()
    {
      return mNickCompletionCaseSensitiveItem;
    }

    /**
      Set BufferSize
    */
    void setDccBufferSize( int v )
    {
      if (!isDccBufferSizeImmutable())
        mDccBufferSize = v;
    }

    /**
      Get BufferSize
    */
    int dccBufferSize() const
    {
      return mDccBufferSize;
    }

    /**
      Is BufferSize Immutable
    */
    bool isDccBufferSizeImmutable() const
    {
      return isImmutable( QStringLiteral( "DccBufferSize" ) );
    }

    /**
      Get Item object corresponding to DccBufferSize()
    */
    ItemInt *dccBufferSizeItem()
    {
      return mDccBufferSizeItem;
    }

    /**
      Set MethodToGetOwnIp
    */
    void setDccMethodToGetOwnIp( int v )
    {
      if (!isDccMethodToGetOwnIpImmutable())
        mDccMethodToGetOwnIp = v;
    }

    /**
      Get MethodToGetOwnIp
    */
    int dccMethodToGetOwnIp() const
    {
      return mDccMethodToGetOwnIp;
    }

    /**
      Is MethodToGetOwnIp Immutable
    */
    bool isDccMethodToGetOwnIpImmutable() const
    {
      return isImmutable( QStringLiteral( "DccMethodToGetOwnIp" ) );
    }

    /**
      Get Item object corresponding to DccMethodToGetOwnIp()
    */
    ItemInt *dccMethodToGetOwnIpItem()
    {
      return mDccMethodToGetOwnIpItem;
    }

    /**
      Set SpecificOwnIp
    */
    void setDccSpecificOwnIp( const QString & v )
    {
      if (!isDccSpecificOwnIpImmutable())
        mDccSpecificOwnIp = v;
    }

    /**
      Get SpecificOwnIp
    */
    QString dccSpecificOwnIp() const
    {
      return mDccSpecificOwnIp;
    }

    /**
      Is SpecificOwnIp Immutable
    */
    bool isDccSpecificOwnIpImmutable() const
    {
      return isImmutable( QStringLiteral( "DccSpecificOwnIp" ) );
    }

    /**
      Get Item object corresponding to DccSpecificOwnIp()
    */
    ItemString *dccSpecificOwnIpItem()
    {
      return mDccSpecificOwnIpItem;
    }

    /**
      Set SpecificSendPorts
    */
    void setDccSpecificSendPorts( bool v )
    {
      if (!isDccSpecificSendPortsImmutable())
        mDccSpecificSendPorts = v;
    }

    /**
      Get SpecificSendPorts
    */
    bool dccSpecificSendPorts() const
    {
      return mDccSpecificSendPorts;
    }

    /**
      Is SpecificSendPorts Immutable
    */
    bool isDccSpecificSendPortsImmutable() const
    {
      return isImmutable( QStringLiteral( "DccSpecificSendPorts" ) );
    }

    /**
      Get Item object corresponding to DccSpecificSendPorts()
    */
    ItemBool *dccSpecificSendPortsItem()
    {
      return mDccSpecificSendPortsItem;
    }

    /**
      Set SendPortsFirst
    */
    void setDccSendPortsFirst( int v )
    {
      if (!isDccSendPortsFirstImmutable())
        mDccSendPortsFirst = v;
    }

    /**
      Get SendPortsFirst
    */
    int dccSendPortsFirst() const
    {
      return mDccSendPortsFirst;
    }

    /**
      Is SendPortsFirst Immutable
    */
    bool isDccSendPortsFirstImmutable() const
    {
      return isImmutable( QStringLiteral( "DccSendPortsFirst" ) );
    }

    /**
      Get Item object corresponding to DccSendPortsFirst()
    */
    ItemInt *dccSendPortsFirstItem()
    {
      return mDccSendPortsFirstItem;
    }

    /**
      Set SendPortsLast
    */
    void setDccSendPortsLast( uint v )
    {
      if (!isDccSendPortsLastImmutable())
        mDccSendPortsLast = v;
    }

    /**
      Get SendPortsLast
    */
    uint dccSendPortsLast() const
    {
      return mDccSendPortsLast;
    }

    /**
      Is SendPortsLast Immutable
    */
    bool isDccSendPortsLastImmutable() const
    {
      return isImmutable( QStringLiteral( "DccSendPortsLast" ) );
    }

    /**
      Get Item object corresponding to DccSendPortsLast()
    */
    ItemUInt *dccSendPortsLastItem()
    {
      return mDccSendPortsLastItem;
    }

    /**
      Set SpecificChatPorts
    */
    void setDccSpecificChatPorts( bool v )
    {
      if (!isDccSpecificChatPortsImmutable())
        mDccSpecificChatPorts = v;
    }

    /**
      Get SpecificChatPorts
    */
    bool dccSpecificChatPorts() const
    {
      return mDccSpecificChatPorts;
    }

    /**
      Is SpecificChatPorts Immutable
    */
    bool isDccSpecificChatPortsImmutable() const
    {
      return isImmutable( QStringLiteral( "DccSpecificChatPorts" ) );
    }

    /**
      Get Item object corresponding to DccSpecificChatPorts()
    */
    ItemBool *dccSpecificChatPortsItem()
    {
      return mDccSpecificChatPortsItem;
    }

    /**
      Set ChatPortsFirst
    */
    void setDccChatPortsFirst( int v )
    {
      if (!isDccChatPortsFirstImmutable())
        mDccChatPortsFirst = v;
    }

    /**
      Get ChatPortsFirst
    */
    int dccChatPortsFirst() const
    {
      return mDccChatPortsFirst;
    }

    /**
      Is ChatPortsFirst Immutable
    */
    bool isDccChatPortsFirstImmutable() const
    {
      return isImmutable( QStringLiteral( "DccChatPortsFirst" ) );
    }

    /**
      Get Item object corresponding to DccChatPortsFirst()
    */
    ItemInt *dccChatPortsFirstItem()
    {
      return mDccChatPortsFirstItem;
    }

    /**
      Set ChatPortsLast
    */
    void setDccChatPortsLast( uint v )
    {
      if (!isDccChatPortsLastImmutable())
        mDccChatPortsLast = v;
    }

    /**
      Get ChatPortsLast
    */
    uint dccChatPortsLast() const
    {
      return mDccChatPortsLast;
    }

    /**
      Is ChatPortsLast Immutable
    */
    bool isDccChatPortsLastImmutable() const
    {
      return isImmutable( QStringLiteral( "DccChatPortsLast" ) );
    }

    /**
      Get Item object corresponding to DccChatPortsLast()
    */
    ItemUInt *dccChatPortsLastItem()
    {
      return mDccChatPortsLastItem;
    }

    /**
      Set AddPartner
    */
    void setDccAddPartner( bool v )
    {
      if (!isDccAddPartnerImmutable())
        mDccAddPartner = v;
    }

    /**
      Get AddPartner
    */
    bool dccAddPartner() const
    {
      return mDccAddPartner;
    }

    /**
      Is AddPartner Immutable
    */
    bool isDccAddPartnerImmutable() const
    {
      return isImmutable( QStringLiteral( "DccAddPartner" ) );
    }

    /**
      Get Item object corresponding to DccAddPartner()
    */
    ItemBool *dccAddPartnerItem()
    {
      return mDccAddPartnerItem;
    }

    /**
      Set CreateFolder
    */
    void setDccCreateFolder( bool v )
    {
      if (!isDccCreateFolderImmutable())
        mDccCreateFolder = v;
    }

    /**
      Get CreateFolder
    */
    bool dccCreateFolder() const
    {
      return mDccCreateFolder;
    }

    /**
      Is CreateFolder Immutable
    */
    bool isDccCreateFolderImmutable() const
    {
      return isImmutable( QStringLiteral( "DccCreateFolder" ) );
    }

    /**
      Get Item object corresponding to DccCreateFolder()
    */
    ItemBool *dccCreateFolderItem()
    {
      return mDccCreateFolderItem;
    }

    /**
      Set SpaceToUnderscore
    */
    void setDccSpaceToUnderscore( bool v )
    {
      if (!isDccSpaceToUnderscoreImmutable())
        mDccSpaceToUnderscore = v;
    }

    /**
      Get SpaceToUnderscore
    */
    bool dccSpaceToUnderscore() const
    {
      return mDccSpaceToUnderscore;
    }

    /**
      Is SpaceToUnderscore Immutable
    */
    bool isDccSpaceToUnderscoreImmutable() const
    {
      return isImmutable( QStringLiteral( "DccSpaceToUnderscore" ) );
    }

    /**
      Get Item object corresponding to DccSpaceToUnderscore()
    */
    ItemBool *dccSpaceToUnderscoreItem()
    {
      return mDccSpaceToUnderscoreItem;
    }

    /**
      Set AutoGet
    */
    void setDccAutoGet( bool v )
    {
      if (!isDccAutoGetImmutable())
        mDccAutoGet = v;
    }

    /**
      Get AutoGet
    */
    bool dccAutoGet() const
    {
      return mDccAutoGet;
    }

    /**
      Is AutoGet Immutable
    */
    bool isDccAutoGetImmutable() const
    {
      return isImmutable( QStringLiteral( "DccAutoGet" ) );
    }

    /**
      Get Item object corresponding to DccAutoGet()
    */
    ItemBool *dccAutoGetItem()
    {
      return mDccAutoGetItem;
    }

    /**
      Set AutoResume
    */
    void setDccAutoResume( bool v )
    {
      if (!isDccAutoResumeImmutable())
        mDccAutoResume = v;
    }

    /**
      Get AutoResume
    */
    bool dccAutoResume() const
    {
      return mDccAutoResume;
    }

    /**
      Is AutoResume Immutable
    */
    bool isDccAutoResumeImmutable() const
    {
      return isImmutable( QStringLiteral( "DccAutoResume" ) );
    }

    /**
      Get Item object corresponding to DccAutoResume()
    */
    ItemBool *dccAutoResumeItem()
    {
      return mDccAutoResumeItem;
    }

    /**
      Set ChatAutoAccept
    */
    void setDccChatAutoAccept( bool v )
    {
      if (!isDccChatAutoAcceptImmutable())
        mDccChatAutoAccept = v;
    }

    /**
      Get ChatAutoAccept
    */
    bool dccChatAutoAccept() const
    {
      return mDccChatAutoAccept;
    }

    /**
      Is ChatAutoAccept Immutable
    */
    bool isDccChatAutoAcceptImmutable() const
    {
      return isImmutable( QStringLiteral( "DccChatAutoAccept" ) );
    }

    /**
      Get Item object corresponding to DccChatAutoAccept()
    */
    ItemBool *dccChatAutoAcceptItem()
    {
      return mDccChatAutoAcceptItem;
    }

    /**
      Set FastSend
    */
    void setDccFastSend( bool v )
    {
      if (!isDccFastSendImmutable())
        mDccFastSend = v;
    }

    /**
      Get FastSend
    */
    bool dccFastSend() const
    {
      return mDccFastSend;
    }

    /**
      Is FastSend Immutable
    */
    bool isDccFastSendImmutable() const
    {
      return isImmutable( QStringLiteral( "DccFastSend" ) );
    }

    /**
      Get Item object corresponding to DccFastSend()
    */
    ItemBool *dccFastSendItem()
    {
      return mDccFastSendItem;
    }

    /**
      Set SendTimeout
    */
    void setDccSendTimeout( int v )
    {
      if (!isDccSendTimeoutImmutable())
        mDccSendTimeout = v;
    }

    /**
      Get SendTimeout
    */
    int dccSendTimeout() const
    {
      return mDccSendTimeout;
    }

    /**
      Is SendTimeout Immutable
    */
    bool isDccSendTimeoutImmutable() const
    {
      return isImmutable( QStringLiteral( "DccSendTimeout" ) );
    }

    /**
      Get Item object corresponding to DccSendTimeout()
    */
    ItemInt *dccSendTimeoutItem()
    {
      return mDccSendTimeoutItem;
    }

    /**
      Set IPv4Fallback
    */
    void setDccIPv4Fallback( bool v )
    {
      if (!isDccIPv4FallbackImmutable())
        mDccIPv4Fallback = v;
    }

    /**
      Get IPv4Fallback
    */
    bool dccIPv4Fallback() const
    {
      return mDccIPv4Fallback;
    }

    /**
      Is IPv4Fallback Immutable
    */
    bool isDccIPv4FallbackImmutable() const
    {
      return isImmutable( QStringLiteral( "DccIPv4Fallback" ) );
    }

    /**
      Get Item object corresponding to DccIPv4Fallback()
    */
    ItemBool *dccIPv4FallbackItem()
    {
      return mDccIPv4FallbackItem;
    }

    /**
      Set IPv4FallbackIface
    */
    void setDccIPv4FallbackIface( const QString & v )
    {
      if (!isDccIPv4FallbackIfaceImmutable())
        mDccIPv4FallbackIface = v;
    }

    /**
      Get IPv4FallbackIface
    */
    QString dccIPv4FallbackIface() const
    {
      return mDccIPv4FallbackIface;
    }

    /**
      Is IPv4FallbackIface Immutable
    */
    bool isDccIPv4FallbackIfaceImmutable() const
    {
      return isImmutable( QStringLiteral( "DccIPv4FallbackIface" ) );
    }

    /**
      Get Item object corresponding to DccIPv4FallbackIface()
    */
    ItemString *dccIPv4FallbackIfaceItem()
    {
      return mDccIPv4FallbackIfaceItem;
    }

    /**
      Set PassiveSend
    */
    void setDccPassiveSend( bool v )
    {
      if (!isDccPassiveSendImmutable())
        mDccPassiveSend = v;
    }

    /**
      Get PassiveSend
    */
    bool dccPassiveSend() const
    {
      return mDccPassiveSend;
    }

    /**
      Is PassiveSend Immutable
    */
    bool isDccPassiveSendImmutable() const
    {
      return isImmutable( QStringLiteral( "DccPassiveSend" ) );
    }

    /**
      Get Item object corresponding to DccPassiveSend()
    */
    ItemBool *dccPassiveSendItem()
    {
      return mDccPassiveSendItem;
    }

    /**
      Set UPnP
    */
    void setDccUPnP( bool v )
    {
      if (!isDccUPnPImmutable())
        mDccUPnP = v;
    }

    /**
      Get UPnP
    */
    bool dccUPnP() const
    {
      return mDccUPnP;
    }

    /**
      Is UPnP Immutable
    */
    bool isDccUPnPImmutable() const
    {
      return isImmutable( QStringLiteral( "DccUPnP" ) );
    }

    /**
      Get Item object corresponding to DccUPnP()
    */
    ItemBool *dccUPnPItem()
    {
      return mDccUPnPItem;
    }

    /**
      Set ColumnWidths
    */
    void setDccColumnWidths( const QList<int> & v )
    {
      if (!isDccColumnWidthsImmutable())
        mDccColumnWidths = v;
    }

    /**
      Get ColumnWidths
    */
    QList<int> dccColumnWidths() const
    {
      return mDccColumnWidths;
    }

    /**
      Is ColumnWidths Immutable
    */
    bool isDccColumnWidthsImmutable() const
    {
      return isImmutable( QStringLiteral( "DccColumnWidths" ) );
    }

    /**
      Get Item object corresponding to DccColumnWidths()
    */
    ItemIntList *dccColumnWidthsItem()
    {
      return mDccColumnWidthsItem;
    }

    /**
      Set ColumnOrder
    */
    void setDccColumnOrders( const QList<int> & v )
    {
      if (!isDccColumnOrdersImmutable())
        mDccColumnOrders = v;
    }

    /**
      Get ColumnOrder
    */
    QList<int> dccColumnOrders() const
    {
      return mDccColumnOrders;
    }

    /**
      Is ColumnOrder Immutable
    */
    bool isDccColumnOrdersImmutable() const
    {
      return isImmutable( QStringLiteral( "DccColumnOrders" ) );
    }

    /**
      Get Item object corresponding to DccColumnOrders()
    */
    ItemIntList *dccColumnOrdersItem()
    {
      return mDccColumnOrdersItem;
    }

    /**
      Set ColumnVisible
    */
    void setDccColumnVisibles( const QList<int> & v )
    {
      if (!isDccColumnVisiblesImmutable())
        mDccColumnVisibles = v;
    }

    /**
      Get ColumnVisible
    */
    QList<int> dccColumnVisibles() const
    {
      return mDccColumnVisibles;
    }

    /**
      Is ColumnVisible Immutable
    */
    bool isDccColumnVisiblesImmutable() const
    {
      return isImmutable( QStringLiteral( "DccColumnVisibles" ) );
    }

    /**
      Get Item object corresponding to DccColumnVisibles()
    */
    ItemIntList *dccColumnVisiblesItem()
    {
      return mDccColumnVisiblesItem;
    }

    /**
      Set ColumnSorted
    */
    void setDccColumnSorted( int v )
    {
      if (!isDccColumnSortedImmutable())
        mDccColumnSorted = v;
    }

    /**
      Get ColumnSorted
    */
    int dccColumnSorted() const
    {
      return mDccColumnSorted;
    }

    /**
      Is ColumnSorted Immutable
    */
    bool isDccColumnSortedImmutable() const
    {
      return isImmutable( QStringLiteral( "DccColumnSorted" ) );
    }

    /**
      Get Item object corresponding to DccColumnSorted()
    */
    ItemInt *dccColumnSortedItem()
    {
      return mDccColumnSortedItem;
    }

    /**
      Set ColumnSortDescending
    */
    void setDccColumnSortDescending( bool v )
    {
      if (!isDccColumnSortDescendingImmutable())
        mDccColumnSortDescending = v;
    }

    /**
      Get ColumnSortDescending
    */
    bool dccColumnSortDescending() const
    {
      return mDccColumnSortDescending;
    }

    /**
      Is ColumnSortDescending Immutable
    */
    bool isDccColumnSortDescendingImmutable() const
    {
      return isImmutable( QStringLiteral( "DccColumnSortDescending" ) );
    }

    /**
      Get Item object corresponding to DccColumnSortDescending()
    */
    ItemBool *dccColumnSortDescendingItem()
    {
      return mDccColumnSortDescendingItem;
    }

    /**
      Set LogfilePath
    */
    void setLogfilePath( const QUrl & v )
    {
      if (!isLogfilePathImmutable())
        mLogfilePath = v;
    }

    /**
      Get LogfilePath
    */
    QUrl logfilePath() const
    {
      return mLogfilePath;
    }

    /**
      Is LogfilePath Immutable
    */
    bool isLogfilePathImmutable() const
    {
      return isImmutable( QStringLiteral( "LogfilePath" ) );
    }

    /**
      Get Item object corresponding to LogfilePath()
    */
    ItemUrl *logfilePathItem()
    {
      return mLogfilePathItem;
    }

    /**
      Set DccPath
    */
    void setDccPath( const QUrl & v )
    {
      if (!isDccPathImmutable())
        mDccPath = v;
    }

    /**
      Get DccPath
    */
    QUrl dccPath() const
    {
      return mDccPath;
    }

    /**
      Is DccPath Immutable
    */
    bool isDccPathImmutable() const
    {
      return isImmutable( QStringLiteral( "DccPath" ) );
    }

    /**
      Get Item object corresponding to DccPath()
    */
    ItemUrl *dccPathItem()
    {
      return mDccPathItem;
    }

    /**
      Set Log
    */
    void setLog( bool v )
    {
      if (!isLogImmutable())
        mLog = v;
    }

    /**
      Get Log
    */
    bool log() const
    {
      return mLog;
    }

    /**
      Is Log Immutable
    */
    bool isLogImmutable() const
    {
      return isImmutable( QStringLiteral( "Log" ) );
    }

    /**
      Get Item object corresponding to Log()
    */
    ItemBool *logItem()
    {
      return mLogItem;
    }

    /**
      Set LowerLog
    */
    void setLowerLog( bool v )
    {
      if (!isLowerLogImmutable())
        mLowerLog = v;
    }

    /**
      Get LowerLog
    */
    bool lowerLog() const
    {
      return mLowerLog;
    }

    /**
      Is LowerLog Immutable
    */
    bool isLowerLogImmutable() const
    {
      return isImmutable( QStringLiteral( "LowerLog" ) );
    }

    /**
      Get Item object corresponding to LowerLog()
    */
    ItemBool *lowerLogItem()
    {
      return mLowerLogItem;
    }

    /**
      Set AddHostnameToLog
    */
    void setAddHostnameToLog( bool v )
    {
      if (!isAddHostnameToLogImmutable())
        mAddHostnameToLog = v;
    }

    /**
      Get AddHostnameToLog
    */
    bool addHostnameToLog() const
    {
      return mAddHostnameToLog;
    }

    /**
      Is AddHostnameToLog Immutable
    */
    bool isAddHostnameToLogImmutable() const
    {
      return isImmutable( QStringLiteral( "AddHostnameToLog" ) );
    }

    /**
      Get Item object corresponding to AddHostnameToLog()
    */
    ItemBool *addHostnameToLogItem()
    {
      return mAddHostnameToLogItem;
    }

    /**
      Set PrivateOnly
    */
    void setPrivateOnly( bool v )
    {
      if (!isPrivateOnlyImmutable())
        mPrivateOnly = v;
    }

    /**
      Get PrivateOnly
    */
    bool privateOnly() const
    {
      return mPrivateOnly;
    }

    /**
      Is PrivateOnly Immutable
    */
    bool isPrivateOnlyImmutable() const
    {
      return isImmutable( QStringLiteral( "PrivateOnly" ) );
    }

    /**
      Get Item object corresponding to PrivateOnly()
    */
    ItemBool *privateOnlyItem()
    {
      return mPrivateOnlyItem;
    }

    /**
      Set TabPlacement
    */
    void setTabPlacement( int v )
    {
      if (!isTabPlacementImmutable())
        mTabPlacement = v;
    }

    /**
      Get TabPlacement
    */
    int tabPlacement() const
    {
      return mTabPlacement;
    }

    /**
      Is TabPlacement Immutable
    */
    bool isTabPlacementImmutable() const
    {
      return isImmutable( QStringLiteral( "TabPlacement" ) );
    }

    /**
      Get Item object corresponding to TabPlacement()
    */
    ItemEnum *tabPlacementItem()
    {
      return mTabPlacementItem;
    }

    /**
      Set MiddleClickClose
    */
    void setMiddleClickClose( bool v )
    {
      if (!isMiddleClickCloseImmutable())
        mMiddleClickClose = v;
    }

    /**
      Get MiddleClickClose
    */
    bool middleClickClose() const
    {
      return mMiddleClickClose;
    }

    /**
      Is MiddleClickClose Immutable
    */
    bool isMiddleClickCloseImmutable() const
    {
      return isImmutable( QStringLiteral( "MiddleClickClose" ) );
    }

    /**
      Get Item object corresponding to MiddleClickClose()
    */
    ItemBool *middleClickCloseItem()
    {
      return mMiddleClickCloseItem;
    }

    /**
      Set UseClickableNicks
    */
    void setUseClickableNicks( bool v )
    {
      if (!isUseClickableNicksImmutable())
        mUseClickableNicks = v;
    }

    /**
      Get UseClickableNicks
    */
    bool useClickableNicks() const
    {
      return mUseClickableNicks;
    }

    /**
      Is UseClickableNicks Immutable
    */
    bool isUseClickableNicksImmutable() const
    {
      return isImmutable( QStringLiteral( "UseClickableNicks" ) );
    }

    /**
      Get Item object corresponding to UseClickableNicks()
    */
    ItemBool *useClickableNicksItem()
    {
      return mUseClickableNicksItem;
    }

    /**
      Set BringToFront
    */
    void setBringToFront( bool v )
    {
      if (!isBringToFrontImmutable())
        mBringToFront = v;
    }

    /**
      Get BringToFront
    */
    bool bringToFront() const
    {
      return mBringToFront;
    }

    /**
      Is BringToFront Immutable
    */
    bool isBringToFrontImmutable() const
    {
      return isImmutable( QStringLiteral( "BringToFront" ) );
    }

    /**
      Get Item object corresponding to BringToFront()
    */
    ItemBool *bringToFrontItem()
    {
      return mBringToFrontItem;
    }

    /**
      Set HideUnimportantEvents
    */
    void setHideUnimportantEvents( bool v )
    {
      if (!isHideUnimportantEventsImmutable())
        mHideUnimportantEvents = v;
    }

    /**
      Get HideUnimportantEvents
    */
    bool hideUnimportantEvents() const
    {
      return mHideUnimportantEvents;
    }

    /**
      Is HideUnimportantEvents Immutable
    */
    bool isHideUnimportantEventsImmutable() const
    {
      return isImmutable( QStringLiteral( "HideUnimportantEvents" ) );
    }

    /**
      Get Item object corresponding to HideUnimportantEvents()
    */
    ItemBool *hideUnimportantEventsItem()
    {
      return mHideUnimportantEventsItem;
    }

    /**
      Set HideUnimportantEventsExcludeActive
    */
    void setHideUnimportantEventsExcludeActive( bool v )
    {
      if (!isHideUnimportantEventsExcludeActiveImmutable())
        mHideUnimportantEventsExcludeActive = v;
    }

    /**
      Get HideUnimportantEventsExcludeActive
    */
    bool hideUnimportantEventsExcludeActive() const
    {
      return mHideUnimportantEventsExcludeActive;
    }

    /**
      Is HideUnimportantEventsExcludeActive Immutable
    */
    bool isHideUnimportantEventsExcludeActiveImmutable() const
    {
      return isImmutable( QStringLiteral( "HideUnimportantEventsExcludeActive" ) );
    }

    /**
      Get Item object corresponding to HideUnimportantEventsExcludeActive()
    */
    ItemBool *hideUnimportantEventsExcludeActiveItem()
    {
      return mHideUnimportantEventsExcludeActiveItem;
    }

    /**
      Set HideUnimportantEventsExcludeActiveThreshold
    */
    void setHideUnimportantEventsExcludeActiveThreshold( int v )
    {
      if (!isHideUnimportantEventsExcludeActiveThresholdImmutable())
        mHideUnimportantEventsExcludeActiveThreshold = v;
    }

    /**
      Get HideUnimportantEventsExcludeActiveThreshold
    */
    int hideUnimportantEventsExcludeActiveThreshold() const
    {
      return mHideUnimportantEventsExcludeActiveThreshold;
    }

    /**
      Is HideUnimportantEventsExcludeActiveThreshold Immutable
    */
    bool isHideUnimportantEventsExcludeActiveThresholdImmutable() const
    {
      return isImmutable( QStringLiteral( "HideUnimportantEventsExcludeActiveThreshold" ) );
    }

    /**
      Get Item object corresponding to HideUnimportantEventsExcludeActiveThreshold()
    */
    ItemInt *hideUnimportantEventsExcludeActiveThresholdItem()
    {
      return mHideUnimportantEventsExcludeActiveThresholdItem;
    }

    /**
      Set DisableExpansion
    */
    void setDisableExpansion( bool v )
    {
      if (!isDisableExpansionImmutable())
        mDisableExpansion = v;
    }

    /**
      Get DisableExpansion
    */
    bool disableExpansion() const
    {
      return mDisableExpansion;
    }

    /**
      Is DisableExpansion Immutable
    */
    bool isDisableExpansionImmutable() const
    {
      return isImmutable( QStringLiteral( "DisableExpansion" ) );
    }

    /**
      Get Item object corresponding to DisableExpansion()
    */
    ItemBool *disableExpansionItem()
    {
      return mDisableExpansionItem;
    }

    /**
      Set AutoReconnect
    */
    void setAutoReconnect( bool v )
    {
      if (!isAutoReconnectImmutable())
        mAutoReconnect = v;
    }

    /**
      Get AutoReconnect
    */
    bool autoReconnect() const
    {
      return mAutoReconnect;
    }

    /**
      Is AutoReconnect Immutable
    */
    bool isAutoReconnectImmutable() const
    {
      return isImmutable( QStringLiteral( "AutoReconnect" ) );
    }

    /**
      Get Item object corresponding to AutoReconnect()
    */
    ItemBool *autoReconnectItem()
    {
      return mAutoReconnectItem;
    }

    /**
      Set ReconnectDelay
    */
    void setReconnectDelay( uint v )
    {
      if (!isReconnectDelayImmutable())
        mReconnectDelay = v;
    }

    /**
      Get ReconnectDelay
    */
    uint reconnectDelay() const
    {
      return mReconnectDelay;
    }

    /**
      Is ReconnectDelay Immutable
    */
    bool isReconnectDelayImmutable() const
    {
      return isImmutable( QStringLiteral( "ReconnectDelay" ) );
    }

    /**
      Get Item object corresponding to ReconnectDelay()
    */
    ItemUInt *reconnectDelayItem()
    {
      return mReconnectDelayItem;
    }

    /**
      Set ReconnectCount
    */
    void setReconnectCount( uint v )
    {
      if (!isReconnectCountImmutable())
        mReconnectCount = v;
    }

    /**
      Get ReconnectCount
    */
    uint reconnectCount() const
    {
      return mReconnectCount;
    }

    /**
      Is ReconnectCount Immutable
    */
    bool isReconnectCountImmutable() const
    {
      return isImmutable( QStringLiteral( "ReconnectCount" ) );
    }

    /**
      Get Item object corresponding to ReconnectCount()
    */
    ItemUInt *reconnectCountItem()
    {
      return mReconnectCountItem;
    }

    /**
      Set EncryptionType
    */
    void setEncryptionType( uint v )
    {
      if (!isEncryptionTypeImmutable())
        mEncryptionType = v;
    }

    /**
      Get EncryptionType
    */
    uint encryptionType() const
    {
      return mEncryptionType;
    }

    /**
      Is EncryptionType Immutable
    */
    bool isEncryptionTypeImmutable() const
    {
      return isImmutable( QStringLiteral( "EncryptionType" ) );
    }

    /**
      Get Item object corresponding to EncryptionType()
    */
    ItemUInt *encryptionTypeItem()
    {
      return mEncryptionTypeItem;
    }

    /**
      Set FixedMOTD
    */
    void setFixedMOTD( bool v )
    {
      if (!isFixedMOTDImmutable())
        mFixedMOTD = v;
    }

    /**
      Get FixedMOTD
    */
    bool fixedMOTD() const
    {
      return mFixedMOTD;
    }

    /**
      Is FixedMOTD Immutable
    */
    bool isFixedMOTDImmutable() const
    {
      return isImmutable( QStringLiteral( "FixedMOTD" ) );
    }

    /**
      Get Item object corresponding to FixedMOTD()
    */
    ItemBool *fixedMOTDItem()
    {
      return mFixedMOTDItem;
    }

    /**
      Set SkipMOTD
    */
    void setSkipMOTD( bool v )
    {
      if (!isSkipMOTDImmutable())
        mSkipMOTD = v;
    }

    /**
      Get SkipMOTD
    */
    bool skipMOTD() const
    {
      return mSkipMOTD;
    }

    /**
      Is SkipMOTD Immutable
    */
    bool isSkipMOTDImmutable() const
    {
      return isImmutable( QStringLiteral( "SkipMOTD" ) );
    }

    /**
      Get Item object corresponding to SkipMOTD()
    */
    ItemBool *skipMOTDItem()
    {
      return mSkipMOTDItem;
    }

    /**
      Set ShowServerList
    */
    void setShowServerList( bool v )
    {
      if (!isShowServerListImmutable())
        mShowServerList = v;
    }

    /**
      Get ShowServerList
    */
    bool showServerList() const
    {
      return mShowServerList;
    }

    /**
      Is ShowServerList Immutable
    */
    bool isShowServerListImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowServerList" ) );
    }

    /**
      Get Item object corresponding to ShowServerList()
    */
    ItemBool *showServerListItem()
    {
      return mShowServerListItem;
    }

    /**
      Set InputFieldsBackgroundColor
    */
    void setInputFieldsBackgroundColor( bool v )
    {
      if (!isInputFieldsBackgroundColorImmutable())
        mInputFieldsBackgroundColor = v;
    }

    /**
      Get InputFieldsBackgroundColor
    */
    bool inputFieldsBackgroundColor() const
    {
      return mInputFieldsBackgroundColor;
    }

    /**
      Is InputFieldsBackgroundColor Immutable
    */
    bool isInputFieldsBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "InputFieldsBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to InputFieldsBackgroundColor()
    */
    ItemBool *inputFieldsBackgroundColorItem()
    {
      return mInputFieldsBackgroundColorItem;
    }

    /**
      Set UseCustomBrowser
    */
    void setUseCustomBrowser( bool v )
    {
      if (!isUseCustomBrowserImmutable())
        mUseCustomBrowser = v;
    }

    /**
      Get UseCustomBrowser
    */
    bool useCustomBrowser() const
    {
      return mUseCustomBrowser;
    }

    /**
      Is UseCustomBrowser Immutable
    */
    bool isUseCustomBrowserImmutable() const
    {
      return isImmutable( QStringLiteral( "UseCustomBrowser" ) );
    }

    /**
      Get Item object corresponding to UseCustomBrowser()
    */
    ItemBool *useCustomBrowserItem()
    {
      return mUseCustomBrowserItem;
    }

    /**
      Set WebBrowserCmd
    */
    void setWebBrowserCmd( const QString & v )
    {
      if (!isWebBrowserCmdImmutable())
        mWebBrowserCmd = v;
    }

    /**
      Get WebBrowserCmd
    */
    QString webBrowserCmd() const
    {
      return mWebBrowserCmd;
    }

    /**
      Is WebBrowserCmd Immutable
    */
    bool isWebBrowserCmdImmutable() const
    {
      return isImmutable( QStringLiteral( "WebBrowserCmd" ) );
    }

    /**
      Get Item object corresponding to WebBrowserCmd()
    */
    ItemString *webBrowserCmdItem()
    {
      return mWebBrowserCmdItem;
    }

    /**
      Set UseExternalLogViewer
    */
    void setUseExternalLogViewer( bool v )
    {
      if (!isUseExternalLogViewerImmutable())
        mUseExternalLogViewer = v;
    }

    /**
      Get UseExternalLogViewer
    */
    bool useExternalLogViewer() const
    {
      return mUseExternalLogViewer;
    }

    /**
      Is UseExternalLogViewer Immutable
    */
    bool isUseExternalLogViewerImmutable() const
    {
      return isImmutable( QStringLiteral( "UseExternalLogViewer" ) );
    }

    /**
      Get Item object corresponding to UseExternalLogViewer()
    */
    ItemBool *useExternalLogViewerItem()
    {
      return mUseExternalLogViewerItem;
    }

    /**
      Set IconTheme
    */
    void setIconTheme( const QString & v )
    {
      if (!isIconThemeImmutable())
        mIconTheme = v;
    }

    /**
      Get IconTheme
    */
    QString iconTheme() const
    {
      return mIconTheme;
    }

    /**
      Is IconTheme Immutable
    */
    bool isIconThemeImmutable() const
    {
      return isImmutable( QStringLiteral( "IconTheme" ) );
    }

    /**
      Get Item object corresponding to IconTheme()
    */
    ItemString *iconThemeItem()
    {
      return mIconThemeItem;
    }

    /**
      Set Size
    */
    void setPreferencesDialogSize( const QSize & v )
    {
      if (!isPreferencesDialogSizeImmutable())
        mPreferencesDialogSize = v;
    }

    /**
      Get Size
    */
    QSize preferencesDialogSize() const
    {
      return mPreferencesDialogSize;
    }

    /**
      Is Size Immutable
    */
    bool isPreferencesDialogSizeImmutable() const
    {
      return isImmutable( QStringLiteral( "PreferencesDialogSize" ) );
    }

    /**
      Get Item object corresponding to PreferencesDialogSize()
    */
    ItemSize *preferencesDialogSizeItem()
    {
      return mPreferencesDialogSizeItem;
    }

    /**
      Set LastActiveModule
    */
    void setLastActiveModule( int v )
    {
      if (!isLastActiveModuleImmutable())
        mLastActiveModule = v;
    }

    /**
      Get LastActiveModule
    */
    int lastActiveModule() const
    {
      return mLastActiveModule;
    }

    /**
      Is LastActiveModule Immutable
    */
    bool isLastActiveModuleImmutable() const
    {
      return isImmutable( QStringLiteral( "LastActiveModule" ) );
    }

    /**
      Get Item object corresponding to LastActiveModule()
    */
    ItemInt *lastActiveModuleItem()
    {
      return mLastActiveModuleItem;
    }

    /**
      Set Size
    */
    void setServerListDialogSize( const QSize & v )
    {
      if (!isServerListDialogSizeImmutable())
        mServerListDialogSize = v;
    }

    /**
      Get Size
    */
    QSize serverListDialogSize() const
    {
      return mServerListDialogSize;
    }

    /**
      Is Size Immutable
    */
    bool isServerListDialogSizeImmutable() const
    {
      return isImmutable( QStringLiteral( "ServerListDialogSize" ) );
    }

    /**
      Get Item object corresponding to ServerListDialogSize()
    */
    ItemSize *serverListDialogSizeItem()
    {
      return mServerListDialogSizeItem;
    }

    /**
      Set $(colorName)
    */
    void setColor( int i, const QColor & v )
    {
      if (!isColorImmutable( i ))
        mColor[i] = v;
    }

    /**
      Get $(colorName)
    */
    QColor color( int i ) const
    {
      return mColor[i];
    }

    /**
      Is $(colorName) Immutable
    */
    bool isColorImmutable( int i ) const
    {
      return isImmutable( QStringLiteral( "%1Color" ).arg( QLatin1String( EnumColorNameToString[i] ) ) );
    }

    /**
      Get Item object corresponding to Color()
    */
    ItemColor *colorItem( int i )
    {
      return mColorItem[i];
    }

    /**
      Set TabNotificationsText
    */
    void setTabNotificationsText( bool v )
    {
      if (!isTabNotificationsTextImmutable())
        mTabNotificationsText = v;
    }

    /**
      Get TabNotificationsText
    */
    bool tabNotificationsText() const
    {
      return mTabNotificationsText;
    }

    /**
      Is TabNotificationsText Immutable
    */
    bool isTabNotificationsTextImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsText" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsText()
    */
    ItemBool *tabNotificationsTextItem()
    {
      return mTabNotificationsTextItem;
    }

    /**
      Set TabNotificationsLeds
    */
    void setTabNotificationsLeds( bool v )
    {
      if (!isTabNotificationsLedsImmutable())
        mTabNotificationsLeds = v;
    }

    /**
      Get TabNotificationsLeds
    */
    bool tabNotificationsLeds() const
    {
      return mTabNotificationsLeds;
    }

    /**
      Is TabNotificationsLeds Immutable
    */
    bool isTabNotificationsLedsImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsLeds" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsLeds()
    */
    ItemBool *tabNotificationsLedsItem()
    {
      return mTabNotificationsLedsItem;
    }

    /**
      Set TabNotificationsSystem
    */
    void setTabNotificationsSystem( bool v )
    {
      if (!isTabNotificationsSystemImmutable())
        mTabNotificationsSystem = v;
    }

    /**
      Get TabNotificationsSystem
    */
    bool tabNotificationsSystem() const
    {
      return mTabNotificationsSystem;
    }

    /**
      Is TabNotificationsSystem Immutable
    */
    bool isTabNotificationsSystemImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsSystem" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsSystem()
    */
    ItemBool *tabNotificationsSystemItem()
    {
      return mTabNotificationsSystemItem;
    }

    /**
      Set TabNotificationsSystemColor
    */
    void setTabNotificationsSystemColor( const QColor & v )
    {
      if (!isTabNotificationsSystemColorImmutable())
        mTabNotificationsSystemColor = v;
    }

    /**
      Get TabNotificationsSystemColor
    */
    QColor tabNotificationsSystemColor() const
    {
      return mTabNotificationsSystemColor;
    }

    /**
      Is TabNotificationsSystemColor Immutable
    */
    bool isTabNotificationsSystemColorImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsSystemColor" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsSystemColor()
    */
    ItemColor *tabNotificationsSystemColorItem()
    {
      return mTabNotificationsSystemColorItem;
    }

    /**
      Set TabNotificationsMsgs
    */
    void setTabNotificationsMsgs( bool v )
    {
      if (!isTabNotificationsMsgsImmutable())
        mTabNotificationsMsgs = v;
    }

    /**
      Get TabNotificationsMsgs
    */
    bool tabNotificationsMsgs() const
    {
      return mTabNotificationsMsgs;
    }

    /**
      Is TabNotificationsMsgs Immutable
    */
    bool isTabNotificationsMsgsImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsMsgs" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsMsgs()
    */
    ItemBool *tabNotificationsMsgsItem()
    {
      return mTabNotificationsMsgsItem;
    }

    /**
      Set TabNotificationsMsgsColor
    */
    void setTabNotificationsMsgsColor( const QColor & v )
    {
      if (!isTabNotificationsMsgsColorImmutable())
        mTabNotificationsMsgsColor = v;
    }

    /**
      Get TabNotificationsMsgsColor
    */
    QColor tabNotificationsMsgsColor() const
    {
      return mTabNotificationsMsgsColor;
    }

    /**
      Is TabNotificationsMsgsColor Immutable
    */
    bool isTabNotificationsMsgsColorImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsMsgsColor" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsMsgsColor()
    */
    ItemColor *tabNotificationsMsgsColorItem()
    {
      return mTabNotificationsMsgsColorItem;
    }

    /**
      Set TabNotificationsPrivate
    */
    void setTabNotificationsPrivate( bool v )
    {
      if (!isTabNotificationsPrivateImmutable())
        mTabNotificationsPrivate = v;
    }

    /**
      Get TabNotificationsPrivate
    */
    bool tabNotificationsPrivate() const
    {
      return mTabNotificationsPrivate;
    }

    /**
      Is TabNotificationsPrivate Immutable
    */
    bool isTabNotificationsPrivateImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsPrivate" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsPrivate()
    */
    ItemBool *tabNotificationsPrivateItem()
    {
      return mTabNotificationsPrivateItem;
    }

    /**
      Set TabNotificationsPrivateColor
    */
    void setTabNotificationsPrivateColor( const QColor & v )
    {
      if (!isTabNotificationsPrivateColorImmutable())
        mTabNotificationsPrivateColor = v;
    }

    /**
      Get TabNotificationsPrivateColor
    */
    QColor tabNotificationsPrivateColor() const
    {
      return mTabNotificationsPrivateColor;
    }

    /**
      Is TabNotificationsPrivateColor Immutable
    */
    bool isTabNotificationsPrivateColorImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsPrivateColor" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsPrivateColor()
    */
    ItemColor *tabNotificationsPrivateColorItem()
    {
      return mTabNotificationsPrivateColorItem;
    }

    /**
      Set TabNotificationsEvents
    */
    void setTabNotificationsEvents( bool v )
    {
      if (!isTabNotificationsEventsImmutable())
        mTabNotificationsEvents = v;
    }

    /**
      Get TabNotificationsEvents
    */
    bool tabNotificationsEvents() const
    {
      return mTabNotificationsEvents;
    }

    /**
      Is TabNotificationsEvents Immutable
    */
    bool isTabNotificationsEventsImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsEvents" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsEvents()
    */
    ItemBool *tabNotificationsEventsItem()
    {
      return mTabNotificationsEventsItem;
    }

    /**
      Set TabNotificationsEventsColor
    */
    void setTabNotificationsEventsColor( const QColor & v )
    {
      if (!isTabNotificationsEventsColorImmutable())
        mTabNotificationsEventsColor = v;
    }

    /**
      Get TabNotificationsEventsColor
    */
    QColor tabNotificationsEventsColor() const
    {
      return mTabNotificationsEventsColor;
    }

    /**
      Is TabNotificationsEventsColor Immutable
    */
    bool isTabNotificationsEventsColorImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsEventsColor" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsEventsColor()
    */
    ItemColor *tabNotificationsEventsColorItem()
    {
      return mTabNotificationsEventsColorItem;
    }

    /**
      Set TabNotificationsNick
    */
    void setTabNotificationsNick( bool v )
    {
      if (!isTabNotificationsNickImmutable())
        mTabNotificationsNick = v;
    }

    /**
      Get TabNotificationsNick
    */
    bool tabNotificationsNick() const
    {
      return mTabNotificationsNick;
    }

    /**
      Is TabNotificationsNick Immutable
    */
    bool isTabNotificationsNickImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsNick" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsNick()
    */
    ItemBool *tabNotificationsNickItem()
    {
      return mTabNotificationsNickItem;
    }

    /**
      Set TabNotificationsNickColor
    */
    void setTabNotificationsNickColor( const QColor & v )
    {
      if (!isTabNotificationsNickColorImmutable())
        mTabNotificationsNickColor = v;
    }

    /**
      Get TabNotificationsNickColor
    */
    QColor tabNotificationsNickColor() const
    {
      return mTabNotificationsNickColor;
    }

    /**
      Is TabNotificationsNickColor Immutable
    */
    bool isTabNotificationsNickColorImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsNickColor" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsNickColor()
    */
    ItemColor *tabNotificationsNickColorItem()
    {
      return mTabNotificationsNickColorItem;
    }

    /**
      Set TabNotificationsHighlights
    */
    void setTabNotificationsHighlights( bool v )
    {
      if (!isTabNotificationsHighlightsImmutable())
        mTabNotificationsHighlights = v;
    }

    /**
      Get TabNotificationsHighlights
    */
    bool tabNotificationsHighlights() const
    {
      return mTabNotificationsHighlights;
    }

    /**
      Is TabNotificationsHighlights Immutable
    */
    bool isTabNotificationsHighlightsImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsHighlights" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsHighlights()
    */
    ItemBool *tabNotificationsHighlightsItem()
    {
      return mTabNotificationsHighlightsItem;
    }

    /**
      Set TabNotificationsHighlightsColor
    */
    void setTabNotificationsHighlightsColor( const QColor & v )
    {
      if (!isTabNotificationsHighlightsColorImmutable())
        mTabNotificationsHighlightsColor = v;
    }

    /**
      Get TabNotificationsHighlightsColor
    */
    QColor tabNotificationsHighlightsColor() const
    {
      return mTabNotificationsHighlightsColor;
    }

    /**
      Is TabNotificationsHighlightsColor Immutable
    */
    bool isTabNotificationsHighlightsColorImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsHighlightsColor" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsHighlightsColor()
    */
    ItemColor *tabNotificationsHighlightsColorItem()
    {
      return mTabNotificationsHighlightsColorItem;
    }

    /**
      Set TabNotificationsOverride
    */
    void setTabNotificationsOverride( bool v )
    {
      if (!isTabNotificationsOverrideImmutable())
        mTabNotificationsOverride = v;
    }

    /**
      Get TabNotificationsOverride
    */
    bool tabNotificationsOverride() const
    {
      return mTabNotificationsOverride;
    }

    /**
      Is TabNotificationsOverride Immutable
    */
    bool isTabNotificationsOverrideImmutable() const
    {
      return isImmutable( QStringLiteral( "TabNotificationsOverride" ) );
    }

    /**
      Get Item object corresponding to TabNotificationsOverride()
    */
    ItemBool *tabNotificationsOverrideItem()
    {
      return mTabNotificationsOverrideItem;
    }

    /**
      Set SortOrder
    */
    void setSortOrder( const QString & v )
    {
      if (!isSortOrderImmutable())
        mSortOrder = v;
    }

    /**
      Get SortOrder
    */
    QString sortOrder() const
    {
      return mSortOrder;
    }

    /**
      Is SortOrder Immutable
    */
    bool isSortOrderImmutable() const
    {
      return isImmutable( QStringLiteral( "SortOrder" ) );
    }

    /**
      Get Item object corresponding to SortOrder()
    */
    ItemString *sortOrderItem()
    {
      return mSortOrderItem;
    }

    /**
      Set EmptyingRate $(QueueIndex)
    */
    void setQueueRate( int i, const QList<int> & v )
    {
      if (!isQueueRateImmutable( i ))
        mQueueRate[i] = v;
    }

    /**
      Get EmptyingRate $(QueueIndex)
    */
    QList<int> queueRate( int i ) const
    {
      return mQueueRate[i];
    }

    /**
      Is EmptyingRate $(QueueIndex) Immutable
    */
    bool isQueueRateImmutable( int i ) const
    {
      return isImmutable( QStringLiteral( "queueRate%1" ).arg( i ) );
    }

    /**
      Get Item object corresponding to queueRate()
    */
    ItemIntList *queueRateItem( int i )
    {
      return mQueueRateItem[i];
    }

    /**
      Set ShowQueueTuner
    */
    void setShowQueueTuner( bool v )
    {
      if (!isShowQueueTunerImmutable())
        mShowQueueTuner = v;
    }

    /**
      Get ShowQueueTuner
    */
    bool showQueueTuner() const
    {
      return mShowQueueTuner;
    }

    /**
      Is ShowQueueTuner Immutable
    */
    bool isShowQueueTunerImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowQueueTuner" ) );
    }

    /**
      Get Item object corresponding to ShowQueueTuner()
    */
    ItemBool *showQueueTunerItem()
    {
      return mShowQueueTunerItem;
    }

    /**
      Set ProxyEnabled
    */
    void setProxyEnabled( bool v )
    {
      if (!isProxyEnabledImmutable())
        mProxyEnabled = v;
    }

    /**
      Get ProxyEnabled
    */
    bool proxyEnabled() const
    {
      return mProxyEnabled;
    }

    /**
      Is ProxyEnabled Immutable
    */
    bool isProxyEnabledImmutable() const
    {
      return isImmutable( QStringLiteral( "ProxyEnabled" ) );
    }

    /**
      Get Item object corresponding to ProxyEnabled()
    */
    ItemBool *proxyEnabledItem()
    {
      return mProxyEnabledItem;
    }

    /**
      Set ProxyType
    */
    void setProxyType( int v )
    {
      if (!isProxyTypeImmutable())
        mProxyType = v;
    }

    /**
      Get ProxyType
    */
    int proxyType() const
    {
      return mProxyType;
    }

    /**
      Is ProxyType Immutable
    */
    bool isProxyTypeImmutable() const
    {
      return isImmutable( QStringLiteral( "ProxyType" ) );
    }

    /**
      Get Item object corresponding to ProxyType()
    */
    ItemEnum *proxyTypeItem()
    {
      return mProxyTypeItem;
    }

    /**
      Set ProxyAddress
    */
    void setProxyAddress( const QString & v )
    {
      if (!isProxyAddressImmutable())
        mProxyAddress = v;
    }

    /**
      Get ProxyAddress
    */
    QString proxyAddress() const
    {
      return mProxyAddress;
    }

    /**
      Is ProxyAddress Immutable
    */
    bool isProxyAddressImmutable() const
    {
      return isImmutable( QStringLiteral( "ProxyAddress" ) );
    }

    /**
      Get Item object corresponding to ProxyAddress()
    */
    ItemString *proxyAddressItem()
    {
      return mProxyAddressItem;
    }

    /**
      Set ProxyPort
    */
    void setProxyPort( int v )
    {
      if (!isProxyPortImmutable())
        mProxyPort = v;
    }

    /**
      Get ProxyPort
    */
    int proxyPort() const
    {
      return mProxyPort;
    }

    /**
      Is ProxyPort Immutable
    */
    bool isProxyPortImmutable() const
    {
      return isImmutable( QStringLiteral( "ProxyPort" ) );
    }

    /**
      Get Item object corresponding to ProxyPort()
    */
    ItemInt *proxyPortItem()
    {
      return mProxyPortItem;
    }

    /**
      Set ProxyUsername
    */
    void setProxyUsername( const QString & v )
    {
      if (!isProxyUsernameImmutable())
        mProxyUsername = v;
    }

    /**
      Get ProxyUsername
    */
    QString proxyUsername() const
    {
      return mProxyUsername;
    }

    /**
      Is ProxyUsername Immutable
    */
    bool isProxyUsernameImmutable() const
    {
      return isImmutable( QStringLiteral( "ProxyUsername" ) );
    }

    /**
      Get Item object corresponding to ProxyUsername()
    */
    ItemString *proxyUsernameItem()
    {
      return mProxyUsernameItem;
    }

    /**
      Set ProxyPassword
    */
    void setProxyPassword( const QString & v )
    {
      if (!isProxyPasswordImmutable())
        mProxyPassword = v;
    }

    /**
      Get ProxyPassword
    */
    QString proxyPassword() const
    {
      return mProxyPassword;
    }

    /**
      Is ProxyPassword Immutable
    */
    bool isProxyPasswordImmutable() const
    {
      return isImmutable( QStringLiteral( "ProxyPassword" ) );
    }

    /**
      Get Item object corresponding to ProxyPassword()
    */
    ItemString *proxyPasswordItem()
    {
      return mProxyPasswordItem;
    }

  protected:

    // Appearance
    bool mShowMenuBar;
    QFont mTextFont;
    QFont mListFont;
    QFont mTabFont;
    bool mCustomTextFont;
    bool mCustomListFont;
    bool mCustomTabFont;
    bool mTimestamping;
    bool mShowDate;
    bool mShowDateLine;
    QString mTimestampFormat;
    bool mShowBacklog;
    int mBacklogLines;
    bool mShowNickList;
    bool mShowQuickButtons;
    bool mShowQuickButtonsInContextMenu;
    bool mShowModeButtons;
    bool mCloseButtons;
    bool mAutoUserhost;
    bool mUseSpacing;
    int mSpacing;
    int mMargin;
    QUrl mBackgroundImage;
    QColor mIrcColorCode[16];
    bool mAllowColorCodes;
    QColor mNickColor[10];
    bool mUseColoredNicks;
    bool mShowTabBarCloseButton;
    bool mShowTopic;
    bool mShowNicknameBox;
    bool mUseBoldNicks;
    bool mUseLiteralModes;
    bool mFocusNewQueries;
    bool mShowIRCViewScrollBar;

    // General Options
    bool mSpellChecking;
    bool mCustomVersionReplyEnabled;
    QString mCustomVersionReply;
    bool mUseMultiRowInputBox;
    QString mCommandChar;
    QString mPreShellCommand;
    bool mShowTrayIcon;
    bool mTrayNotify;
    bool mTrayNotifyOnlyOwnNick;
    bool mTrayNotifyBlink;
    bool mHideToTrayOnStartup;
    bool mTrayActivateNoWindow;
    bool mShowBackgroundImage;
    QSize mMultilineEditSize;
    int mLogfileBufferSize;
    int mScrollbackMax;
    int mAutoWhoNicksLimit;
    bool mAutoWhoContinuousEnabled;
    int mAutoWhoContinuousInterval;
    bool mShowRealNames;
    QString mChannelDoubleClickAction;
    QString mNotifyDoubleClickAction;
    bool mBeep;
    bool mRawLog;
    QString mVersionReply;
    int mMaximumLagTime;
    bool mRedirectServerAndAppMsgToStatusPane;
    bool mDisableNotifyWhileAway;
    int mAutoAwayPollInterval;
    bool mAutomaticRememberLine;
    bool mAutomaticRememberLineOnlyOnTextChange;
    bool mMarkerLineInAllViews;

    // Sort Nicknames
    bool mSortByStatus;
    bool mSortByActivity;
    bool mSortCaseInsensitive;

    // LauncherEntry
    int mLauncherEntryCountMode;
    bool mLauncherEntryCountUseNick;
    bool mLauncherEntryCountUseHighlights;
    bool mLauncherEntryCountUsePrivate;
    bool mLauncherEntryCountUseMsgs;
    bool mLauncherEntryCountUseSystem;
    bool mLauncherEntryCountUseChannelEvents;

    // OSD
    bool mUseOSD;
    bool mOSDShowOwnNick;
    bool mOSDShowChannel;
    bool mOSDShowQuery;
    bool mOSDShowChannelEvent;
    QFont mOSDFont;
    bool mOSDUseCustomColors;
    int mOSDDuration;
    int mOSDScreen;
    bool mOSDDrawShadow;
    int mOSDOffsetX;
    int mOSDOffsetY;
    int mOSDAlignment;
    QColor mOSDTextColor;
    QColor mOSDBackgroundColor;
    bool mOSDCheckDesktopLock;

    // Notify List
    int mNotifyDelay;
    bool mUseNotify;
    bool mOpenWatchedNicksAtStartup;

    // Highlight List
    bool mHighlightSoundsEnabled;
    bool mHighlightNick;
    QColor mHighlightNickColor;
    bool mHighlightOwnLines;
    QColor mHighlightOwnLinesColor;
    QString mHighlight;

    // Aliases
    QStringList mAliasList;

    // Nick Completion
    int mNickCompletionMode;
    QString mNickCompleteSuffixStart;
    QString mNickCompleteSuffixMiddle;
    QString mPrefixCharacter;
    bool mNickCompletionCaseSensitive;

    // DCC Settings
    int mDccBufferSize;
    int mDccMethodToGetOwnIp;
    QString mDccSpecificOwnIp;
    bool mDccSpecificSendPorts;
    int mDccSendPortsFirst;
    uint mDccSendPortsLast;
    bool mDccSpecificChatPorts;
    int mDccChatPortsFirst;
    uint mDccChatPortsLast;
    bool mDccAddPartner;
    bool mDccCreateFolder;
    bool mDccSpaceToUnderscore;
    bool mDccAutoGet;
    bool mDccAutoResume;
    bool mDccChatAutoAccept;
    bool mDccFastSend;
    int mDccSendTimeout;
    bool mDccIPv4Fallback;
    QString mDccIPv4FallbackIface;
    bool mDccPassiveSend;
    bool mDccUPnP;
    QList<int> mDccColumnWidths;
    QList<int> mDccColumnOrders;
    QList<int> mDccColumnVisibles;
    int mDccColumnSorted;
    bool mDccColumnSortDescending;

    // Path Settings
    QUrl mLogfilePath;
    QUrl mDccPath;

    // Flags
    bool mLog;
    bool mLowerLog;
    bool mAddHostnameToLog;
    bool mPrivateOnly;
    int mTabPlacement;
    bool mMiddleClickClose;
    bool mUseClickableNicks;
    bool mBringToFront;
    bool mHideUnimportantEvents;
    bool mHideUnimportantEventsExcludeActive;
    int mHideUnimportantEventsExcludeActiveThreshold;
    bool mDisableExpansion;
    bool mAutoReconnect;
    uint mReconnectDelay;
    uint mReconnectCount;
    uint mEncryptionType;
    bool mFixedMOTD;
    bool mSkipMOTD;
    bool mShowServerList;
    bool mInputFieldsBackgroundColor;

    // Web Browser Settings
    bool mUseCustomBrowser;
    QString mWebBrowserCmd;

    // External Log Viewer
    bool mUseExternalLogViewer;

    // Themes
    QString mIconTheme;

    // PreferencesDialog
    QSize mPreferencesDialogSize;
    int mLastActiveModule;

    // ServerListDialog
    QSize mServerListDialogSize;

    // Message Text Colors
    QColor mColor[11];

    // Tab Notifications
    bool mTabNotificationsText;
    bool mTabNotificationsLeds;
    bool mTabNotificationsSystem;
    QColor mTabNotificationsSystemColor;
    bool mTabNotificationsMsgs;
    QColor mTabNotificationsMsgsColor;
    bool mTabNotificationsPrivate;
    QColor mTabNotificationsPrivateColor;
    bool mTabNotificationsEvents;
    QColor mTabNotificationsEventsColor;
    bool mTabNotificationsNick;
    QColor mTabNotificationsNickColor;
    bool mTabNotificationsHighlights;
    QColor mTabNotificationsHighlightsColor;
    bool mTabNotificationsOverride;

    // Sort Nicknames
    QString mSortOrder;

    // QueueRates
    QList<int> mQueueRate[3];
    bool mShowQueueTuner;

    // Proxy
    bool mProxyEnabled;
    int mProxyType;
    QString mProxyAddress;
    int mProxyPort;
    QString mProxyUsername;
    QString mProxyPassword;

  private:
    ItemBool *mShowMenuBarItem;
    ItemFont *mTextFontItem;
    ItemFont *mListFontItem;
    ItemFont *mTabFontItem;
    ItemBool *mCustomTextFontItem;
    ItemBool *mCustomListFontItem;
    ItemBool *mCustomTabFontItem;
    ItemBool *mTimestampingItem;
    ItemBool *mShowDateItem;
    ItemBool *mShowDateLineItem;
    ItemString *mTimestampFormatItem;
    ItemBool *mShowBacklogItem;
    ItemInt *mBacklogLinesItem;
    ItemBool *mShowNickListItem;
    ItemBool *mShowQuickButtonsItem;
    ItemBool *mShowQuickButtonsInContextMenuItem;
    ItemBool *mShowModeButtonsItem;
    ItemBool *mCloseButtonsItem;
    ItemBool *mAutoUserhostItem;
    ItemBool *mUseSpacingItem;
    ItemInt *mSpacingItem;
    ItemInt *mMarginItem;
    ItemUrl *mBackgroundImageItem;
    ItemColor *mIrcColorCodeItem[16];
    ItemBool *mAllowColorCodesItem;
    ItemColor *mNickColorItem[10];
    ItemBool *mUseColoredNicksItem;
    ItemBool *mShowTabBarCloseButtonItem;
    ItemBool *mShowTopicItem;
    ItemBool *mShowNicknameBoxItem;
    ItemBool *mUseBoldNicksItem;
    ItemBool *mUseLiteralModesItem;
    ItemBool *mFocusNewQueriesItem;
    ItemBool *mShowIRCViewScrollBarItem;
    ItemBool *mSpellCheckingItem;
    ItemBool *mCustomVersionReplyEnabledItem;
    ItemString *mCustomVersionReplyItem;
    ItemBool *mUseMultiRowInputBoxItem;
    ItemString *mCommandCharItem;
    ItemString *mPreShellCommandItem;
    ItemBool *mShowTrayIconItem;
    ItemBool *mTrayNotifyItem;
    ItemBool *mTrayNotifyOnlyOwnNickItem;
    ItemBool *mTrayNotifyBlinkItem;
    ItemBool *mHideToTrayOnStartupItem;
    ItemBool *mTrayActivateNoWindowItem;
    ItemBool *mShowBackgroundImageItem;
    ItemSize *mMultilineEditSizeItem;
    ItemInt *mLogfileBufferSizeItem;
    ItemInt *mScrollbackMaxItem;
    ItemInt *mAutoWhoNicksLimitItem;
    ItemBool *mAutoWhoContinuousEnabledItem;
    ItemInt *mAutoWhoContinuousIntervalItem;
    ItemBool *mShowRealNamesItem;
    ItemString *mChannelDoubleClickActionItem;
    ItemString *mNotifyDoubleClickActionItem;
    ItemBool *mBeepItem;
    ItemBool *mRawLogItem;
    ItemString *mVersionReplyItem;
    ItemInt *mMaximumLagTimeItem;
    ItemBool *mRedirectServerAndAppMsgToStatusPaneItem;
    ItemBool *mDisableNotifyWhileAwayItem;
    ItemInt *mAutoAwayPollIntervalItem;
    ItemBool *mAutomaticRememberLineItem;
    ItemBool *mAutomaticRememberLineOnlyOnTextChangeItem;
    ItemBool *mMarkerLineInAllViewsItem;
    ItemBool *mSortByStatusItem;
    ItemBool *mSortByActivityItem;
    ItemBool *mSortCaseInsensitiveItem;
    ItemEnum *mLauncherEntryCountModeItem;
    ItemBool *mLauncherEntryCountUseNickItem;
    ItemBool *mLauncherEntryCountUseHighlightsItem;
    ItemBool *mLauncherEntryCountUsePrivateItem;
    ItemBool *mLauncherEntryCountUseMsgsItem;
    ItemBool *mLauncherEntryCountUseSystemItem;
    ItemBool *mLauncherEntryCountUseChannelEventsItem;
    ItemBool *mUseOSDItem;
    ItemBool *mOSDShowOwnNickItem;
    ItemBool *mOSDShowChannelItem;
    ItemBool *mOSDShowQueryItem;
    ItemBool *mOSDShowChannelEventItem;
    ItemFont *mOSDFontItem;
    ItemBool *mOSDUseCustomColorsItem;
    ItemInt *mOSDDurationItem;
    ItemInt *mOSDScreenItem;
    ItemBool *mOSDDrawShadowItem;
    ItemInt *mOSDOffsetXItem;
    ItemInt *mOSDOffsetYItem;
    ItemInt *mOSDAlignmentItem;
    ItemColor *mOSDTextColorItem;
    ItemColor *mOSDBackgroundColorItem;
    ItemBool *mOSDCheckDesktopLockItem;
    ItemInt *mNotifyDelayItem;
    ItemBool *mUseNotifyItem;
    ItemBool *mOpenWatchedNicksAtStartupItem;
    ItemBool *mHighlightSoundsEnabledItem;
    ItemBool *mHighlightNickItem;
    ItemColor *mHighlightNickColorItem;
    ItemBool *mHighlightOwnLinesItem;
    ItemColor *mHighlightOwnLinesColorItem;
    ItemString *mHighlightItem;
    ItemStringList *mAliasListItem;
    ItemInt *mNickCompletionModeItem;
    ItemString *mNickCompleteSuffixStartItem;
    ItemString *mNickCompleteSuffixMiddleItem;
    ItemString *mPrefixCharacterItem;
    ItemBool *mNickCompletionCaseSensitiveItem;
    ItemInt *mDccBufferSizeItem;
    ItemInt *mDccMethodToGetOwnIpItem;
    ItemString *mDccSpecificOwnIpItem;
    ItemBool *mDccSpecificSendPortsItem;
    ItemInt *mDccSendPortsFirstItem;
    ItemUInt *mDccSendPortsLastItem;
    ItemBool *mDccSpecificChatPortsItem;
    ItemInt *mDccChatPortsFirstItem;
    ItemUInt *mDccChatPortsLastItem;
    ItemBool *mDccAddPartnerItem;
    ItemBool *mDccCreateFolderItem;
    ItemBool *mDccSpaceToUnderscoreItem;
    ItemBool *mDccAutoGetItem;
    ItemBool *mDccAutoResumeItem;
    ItemBool *mDccChatAutoAcceptItem;
    ItemBool *mDccFastSendItem;
    ItemInt *mDccSendTimeoutItem;
    ItemBool *mDccIPv4FallbackItem;
    ItemString *mDccIPv4FallbackIfaceItem;
    ItemBool *mDccPassiveSendItem;
    ItemBool *mDccUPnPItem;
    ItemIntList *mDccColumnWidthsItem;
    ItemIntList *mDccColumnOrdersItem;
    ItemIntList *mDccColumnVisiblesItem;
    ItemInt *mDccColumnSortedItem;
    ItemBool *mDccColumnSortDescendingItem;
    ItemUrl *mLogfilePathItem;
    ItemUrl *mDccPathItem;
    ItemBool *mLogItem;
    ItemBool *mLowerLogItem;
    ItemBool *mAddHostnameToLogItem;
    ItemBool *mPrivateOnlyItem;
    ItemEnum *mTabPlacementItem;
    ItemBool *mMiddleClickCloseItem;
    ItemBool *mUseClickableNicksItem;
    ItemBool *mBringToFrontItem;
    ItemBool *mHideUnimportantEventsItem;
    ItemBool *mHideUnimportantEventsExcludeActiveItem;
    ItemInt *mHideUnimportantEventsExcludeActiveThresholdItem;
    ItemBool *mDisableExpansionItem;
    ItemBool *mAutoReconnectItem;
    ItemUInt *mReconnectDelayItem;
    ItemUInt *mReconnectCountItem;
    ItemUInt *mEncryptionTypeItem;
    ItemBool *mFixedMOTDItem;
    ItemBool *mSkipMOTDItem;
    ItemBool *mShowServerListItem;
    ItemBool *mInputFieldsBackgroundColorItem;
    ItemBool *mUseCustomBrowserItem;
    ItemString *mWebBrowserCmdItem;
    ItemBool *mUseExternalLogViewerItem;
    ItemString *mIconThemeItem;
    ItemSize *mPreferencesDialogSizeItem;
    ItemInt *mLastActiveModuleItem;
    ItemSize *mServerListDialogSizeItem;
    ItemColor *mColorItem[11];
    ItemBool *mTabNotificationsTextItem;
    ItemBool *mTabNotificationsLedsItem;
    ItemBool *mTabNotificationsSystemItem;
    ItemColor *mTabNotificationsSystemColorItem;
    ItemBool *mTabNotificationsMsgsItem;
    ItemColor *mTabNotificationsMsgsColorItem;
    ItemBool *mTabNotificationsPrivateItem;
    ItemColor *mTabNotificationsPrivateColorItem;
    ItemBool *mTabNotificationsEventsItem;
    ItemColor *mTabNotificationsEventsColorItem;
    ItemBool *mTabNotificationsNickItem;
    ItemColor *mTabNotificationsNickColorItem;
    ItemBool *mTabNotificationsHighlightsItem;
    ItemColor *mTabNotificationsHighlightsColorItem;
    ItemBool *mTabNotificationsOverrideItem;
    ItemString *mSortOrderItem;
    ItemIntList *mQueueRateItem[3];
    ItemBool *mShowQueueTunerItem;
    ItemBool *mProxyEnabledItem;
    ItemEnum *mProxyTypeItem;
    ItemString *mProxyAddressItem;
    ItemInt *mProxyPortItem;
    ItemString *mProxyUsernameItem;
    ItemString *mProxyPasswordItem;
};

#endif

